# Go API client for api

Official API for Major League Baseball.

## Overview
This API client was generated by the [OpenAPI Generator](https://openapi-generator.tech) project.  By using the [OpenAPI-spec](https://www.openapis.org/) from a remote server, you can easily generate an API client.

- API version: 2.0.0
- Package version: 1.0.0
- Generator version: 7.12.0
- Build package: org.openapitools.codegen.languages.GoClientCodegen

## Installation

Install the following dependencies:

```sh
go get github.com/stretchr/testify/assert
go get golang.org/x/net/context
```

Put the package under your project folder and add the following in import:

```go
import api "//"
```

To use a proxy, set the environment variable `HTTP_PROXY`:

```go
os.Setenv("HTTP_PROXY", "http://proxy_name:proxy_port")
```

## Configuration of Server URL

Default configuration comes with `Servers` field that contains server objects as defined in the OpenAPI specification.

### Select Server Configuration

For using other server than the one defined on index 0 set context value `api.ContextServerIndex` of type `int`.

```go
ctx := context.WithValue(context.Background(), api.ContextServerIndex, 1)
```

### Templated Server URL

Templated server URL is formatted using default variables from configuration or from context value `api.ContextServerVariables` of type `map[string]string`.

```go
ctx := context.WithValue(context.Background(), api.ContextServerVariables, map[string]string{
	"basePath": "v2",
})
```

Note, enum values are always validated and all unused variables are silently ignored.

### URLs Configuration per Operation

Each operation can use different server URL defined using `OperationServers` map in the `Configuration`.
An operation is uniquely identified by `"{classname}Service.{nickname}"` string.
Similar rules for overriding default operation server index and variables applies by using `api.ContextOperationServerIndices` and `api.ContextOperationServerVariables` context maps.

```go
ctx := context.WithValue(context.Background(), api.ContextOperationServerIndices, map[string]int{
	"{classname}Service.{nickname}": 2,
})
ctx = context.WithValue(context.Background(), api.ContextOperationServerVariables, map[string]map[string]string{
	"{classname}Service.{nickname}": {
		"port": "8443",
	},
})
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnalyticsAPI* | [**ContextMetrics**](docs/AnalyticsAPI.md#contextmetrics) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetrics | Get context metrics for a specific gamePk.
*AnalyticsAPI* | [**ContextMetricsWithAverages**](docs/AnalyticsAPI.md#contextmetricswithaverages) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
*AnalyticsAPI* | [**ContextMetricsWithAveragesPost**](docs/AnalyticsAPI.md#contextmetricswithaveragespost) | **Post** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
*AnalyticsAPI* | [**GameGuids**](docs/AnalyticsAPI.md#gameguids) | **Get** /api/v1/game/{gamePk}/guids | Get the GUIDs (plays) for a specific game. 
*AnalyticsAPI* | [**GameGuidsFromPostgresRange**](docs/AnalyticsAPI.md#gameguidsfrompostgresrange) | **Get** /api/v1/analytics/guids | Get the GUIDs (plays) for a specific game. 
*AnalyticsAPI* | [**GameGuidsFromPostgresRangeByGame**](docs/AnalyticsAPI.md#gameguidsfrompostgresrangebygame) | **Get** /api/v1/analytics/game | Get all games by updated date.
*AnalyticsAPI* | [**GameLastPitch**](docs/AnalyticsAPI.md#gamelastpitch) | **Get** /api/v1/game/lastPitch | Get the last pitch for a list of games
*AnalyticsAPI* | [**HomeRunBallparks**](docs/AnalyticsAPI.md#homerunballparks) | **Get** /api/v1/game/{gamePk}/{guid}/homeRunBallparks | Get if the play is a home run is each park for a specific play.
*AnalyticsAPI* | [**ParsedJsonFormattedAnalytics**](docs/AnalyticsAPI.md#parsedjsonformattedanalytics) | **Get** /api/v1/game/{gamePk}/{guid}/analytics | Get Statcast data for a specific play.
*AttendanceAPI* | [**GetTeamAttendance**](docs/AttendanceAPI.md#getteamattendance) | **Get** /api/v1/attendance | Get team attendance
*AwardsAPI* | [**AwardRecipients**](docs/AwardsAPI.md#awardrecipients) | **Get** /api/v1/awards/{awardId}/recipients | View recipients of an award
*AwardsAPI* | [**Awards**](docs/AwardsAPI.md#awards) | **Get** /api/v1/awards | View awards info
*AwardsAPI* | [**Awards1**](docs/AwardsAPI.md#awards1) | **Get** /api/v1/awards/{awardId} | View awards info
*BatTrackingAPI* | [**BatTracking**](docs/BatTrackingAPI.md#battracking) | **Get** /api/v1/batTracking/game/{gamePk}/{playId} | View Bat Tracking Data by playId and gameId
*BiomechanicsAPI* | [**Biomechanical**](docs/BiomechanicsAPI.md#biomechanical) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/biomechanics/{positionId} | View Biomechanical data by playId and gameId filtered by player positionId
*BroadcastAPI* | [**GetAllBroadcasters**](docs/BroadcastAPI.md#getallbroadcasters) | **Get** /api/v1/broadcasters | Get All Active Broadcasters
*BroadcastAPI* | [**GetBroadcasts**](docs/BroadcastAPI.md#getbroadcasts) | **Get** /api/v1/broadcast | Get Broadcasters
*ConferenceAPI* | [**Conferences**](docs/ConferenceAPI.md#conferences) | **Get** /api/v1/conferences | View conference info
*ConferenceAPI* | [**Conferences1**](docs/ConferenceAPI.md#conferences1) | **Get** /api/v1/conferences/{conferenceId} | View conference info
*DivisionAPI* | [**Divisions**](docs/DivisionAPI.md#divisions) | **Get** /api/v1/divisions | Get division information
*DivisionAPI* | [**Divisions1**](docs/DivisionAPI.md#divisions1) | **Get** /api/v1/divisions/{divisionId} | Get division information
*DraftAPI* | [**DraftPicks**](docs/DraftAPI.md#draftpicks) | **Get** /api/v1/draft | View MLB Drafted Players
*DraftAPI* | [**DraftPicks1**](docs/DraftAPI.md#draftpicks1) | **Get** /api/v1/draft/{year} | View MLB Drafted Players
*DraftAPI* | [**DraftProspects**](docs/DraftAPI.md#draftprospects) | **Get** /api/v1/draft/prospects | View MLB Draft Prospects
*DraftAPI* | [**DraftProspects1**](docs/DraftAPI.md#draftprospects1) | **Get** /api/v1/draft/prospects/{year} | View MLB Draft Prospects
*DraftAPI* | [**LatestDraftPicks**](docs/DraftAPI.md#latestdraftpicks) | **Get** /api/v1/draft/{year}/latest | Get the last drafted player and the next 5 teams up to pick
*GameAPI* | [**Boxscore**](docs/GameAPI.md#boxscore) | **Get** /api/v1/game/{game_pk}/boxscore | Get game boxscore.
*GameAPI* | [**ColorFeed**](docs/GameAPI.md#colorfeed) | **Get** /api/v1/game/{game_pk}/feed/color | Get game color feed.
*GameAPI* | [**ColorTimestamps**](docs/GameAPI.md#colortimestamps) | **Get** /api/v1/game/{game_pk}/feed/color/timestamps | Retrieve all of the color timestamps for a game.
*GameAPI* | [**Content**](docs/GameAPI.md#content) | **Get** /api/v1/game/{game_pk}/content | Retrieve all content for a game.
*GameAPI* | [**CurrentGameStats1**](docs/GameAPI.md#currentgamestats1) | **Get** /api/v1/game/changes | View a game change log
*GameAPI* | [**GetGameContextMetrics**](docs/GameAPI.md#getgamecontextmetrics) | **Get** /api/v1/game/{gamePk}/contextMetrics | Get the context metrics for this game based on its current state
*GameAPI* | [**GetGameWithMetrics**](docs/GameAPI.md#getgamewithmetrics) | **Get** /api/v1/game/{gamePk}/withMetrics | Get game info with metrics
*GameAPI* | [**GetWinProbability**](docs/GameAPI.md#getwinprobability) | **Get** /api/v1/game/{gamePk}/winProbability | Get the win probability for this game
*GameAPI* | [**Linescore**](docs/GameAPI.md#linescore) | **Get** /api/v1/game/{game_pk}/linescore | Get game linescore
*GameAPI* | [**LiveGameDiffPatchV1**](docs/GameAPI.md#livegamediffpatchv1) | **Get** /api/v1.1/game/{game_pk}/feed/live/diffPatch | Get live game status diffPatch.
*GameAPI* | [**LiveGameV1**](docs/GameAPI.md#livegamev1) | **Get** /api/v1.1/game/{game_pk}/feed/live | Get live game status.
*GameAPI* | [**LiveTimestampv11**](docs/GameAPI.md#livetimestampv11) | **Get** /api/v1.1/game/{game_pk}/feed/live/timestamps | Retrieve all of the play timestamps for a game.
*GameAPI* | [**PlayByPlay**](docs/GameAPI.md#playbyplay) | **Get** /api/v1/game/{game_pk}/playByPlay | Get game play By Play
*GamePaceAPI* | [**GamePace**](docs/GamePaceAPI.md#gamepace) | **Get** /api/v1/gamePace | View time of game info
*HighLowAPI* | [**HighLow**](docs/HighLowAPI.md#highlow) | **Get** /api/v1/highLow/{highLowType} | View high/low stats by player or team
*HighLowAPI* | [**HighLowStats**](docs/HighLowAPI.md#highlowstats) | **Get** /api/v1/highLow/types | View high/low stat types
*HomerunDerbyAPI* | [**HomeRunDerbyBracket**](docs/HomerunDerbyAPI.md#homerunderbybracket) | **Get** /api/v1/homeRunDerby/{gamePk} | View a home run derby object
*HomerunDerbyAPI* | [**HomeRunDerbyBracket1**](docs/HomerunDerbyAPI.md#homerunderbybracket1) | **Get** /api/v1/homeRunDerby | View a home run derby object
*HomerunDerbyAPI* | [**HomeRunDerbyBracket2**](docs/HomerunDerbyAPI.md#homerunderbybracket2) | **Get** /api/v1/homeRunDerby/{gamePk}/bracket | View a home run derby object
*HomerunDerbyAPI* | [**HomeRunDerbyBracket3**](docs/HomerunDerbyAPI.md#homerunderbybracket3) | **Get** /api/v1/homeRunDerby/bracket | View a home run derby object
*HomerunDerbyAPI* | [**HomeRunDerbyMixedMode**](docs/HomerunDerbyAPI.md#homerunderbymixedmode) | **Get** /api/v1/homeRunDerby/{gamePk}/mixed | View home run derby mixed mode (Bracket/Pool combo)
*HomerunDerbyAPI* | [**HomeRunDerbyMixedMode1**](docs/HomerunDerbyAPI.md#homerunderbymixedmode1) | **Get** /api/v1/homeRunDerby/mixed | View home run derby mixed mode (Bracket/Pool combo)
*HomerunDerbyAPI* | [**HomeRunDerbyPool**](docs/HomerunDerbyAPI.md#homerunderbypool) | **Get** /api/v1/homeRunDerby/{gamePk}/pool | View home run derby pool
*HomerunDerbyAPI* | [**HomeRunDerbyPool1**](docs/HomerunDerbyAPI.md#homerunderbypool1) | **Get** /api/v1/homeRunDerby/pool | View home run derby pool
*JobAPI* | [**Datacasters**](docs/JobAPI.md#datacasters) | **Get** /api/v1/jobs/datacasters | Get datacaster jobs
*JobAPI* | [**GetJobsByType**](docs/JobAPI.md#getjobsbytype) | **Get** /api/v1/jobs | Get jobs by type
*JobAPI* | [**OfficialScorers**](docs/JobAPI.md#officialscorers) | **Get** /api/v1/jobs/officialScorers | Get official scorers
*JobAPI* | [**UmpireSchedule**](docs/JobAPI.md#umpireschedule) | **Get** /api/v1/jobs/umpires/games/{umpireId} | Get umpires and associated game for umpireId
*JobAPI* | [**Umpires**](docs/JobAPI.md#umpires) | **Get** /api/v1/jobs/umpires | Get umpires
*LeagueAPI* | [**AllStarBallot**](docs/LeagueAPI.md#allstarballot) | **Get** /api/v1/league/allStarBallot | View al star ballot info
*LeagueAPI* | [**AllStarBallot1**](docs/LeagueAPI.md#allstarballot1) | **Get** /api/v1/league/{leagueId}/allStarBallot | View al star ballot info
*LeagueAPI* | [**AllStarBallot2**](docs/LeagueAPI.md#allstarballot2) | **Get** /api/v1/leagues/allStarBallot | View al star ballot info
*LeagueAPI* | [**AllStarBallot3**](docs/LeagueAPI.md#allstarballot3) | **Get** /api/v1/leagues/{leagueId}/allStarBallot | View al star ballot info
*LeagueAPI* | [**AllStarFinalVote**](docs/LeagueAPI.md#allstarfinalvote) | **Get** /api/v1/league/{leagueId}/allStarFinalVote | View all star final vote info
*LeagueAPI* | [**AllStarFinalVote1**](docs/LeagueAPI.md#allstarfinalvote1) | **Get** /api/v1/leagues/{leagueId}/allStarFinalVote | View all star final vote info
*LeagueAPI* | [**AllStarWriteIns**](docs/LeagueAPI.md#allstarwriteins) | **Get** /api/v1/league/{leagueId}/allStarWriteIns | View all star write ins info
*LeagueAPI* | [**AllStarWriteIns1**](docs/LeagueAPI.md#allstarwriteins1) | **Get** /api/v1/leagues/{leagueId}/allStarWriteIns | View all star write ins info
*LeagueAPI* | [**League**](docs/LeagueAPI.md#league) | **Get** /api/v1/league | View league info
*LeagueAPI* | [**League1**](docs/LeagueAPI.md#league1) | **Get** /api/v1/league/{leagueId} | View league info
*LeagueAPI* | [**League2**](docs/LeagueAPI.md#league2) | **Get** /api/v1/leagues | View league info
*LeagueAPI* | [**League3**](docs/LeagueAPI.md#league3) | **Get** /api/v1/leagues/{leagueId} | View league info
*MilestonesAPI* | [**AchievementStatuses**](docs/MilestonesAPI.md#achievementstatuses) | **Get** /api/v1/achievementStatuses | View available achievementStatus options
*MilestonesAPI* | [**MilestoneDurations**](docs/MilestonesAPI.md#milestonedurations) | **Get** /api/v1/milestoneDurations | View available milestoneDurations options
*MilestonesAPI* | [**MilestoneLookups**](docs/MilestonesAPI.md#milestonelookups) | **Get** /api/v1/milestoneLookups | View available milestoneLookup options
*MilestonesAPI* | [**MilestoneStatistics**](docs/MilestonesAPI.md#milestonestatistics) | **Get** /api/v1/milestoneStatistics | View available milestone statistics options
*MilestonesAPI* | [**MilestoneTypes**](docs/MilestonesAPI.md#milestonetypes) | **Get** /api/v1/milestoneTypes | View available milestoneType options
*MilestonesAPI* | [**Milestones**](docs/MilestonesAPI.md#milestones) | **Get** /api/v1/milestones | View pending and achieved milestones.
*MiscAPI* | [**AggregateSortEnum**](docs/MiscAPI.md#aggregatesortenum) | **Get** /api/v1/sortModifiers | List all stat fields
*MiscAPI* | [**BaseballStats**](docs/MiscAPI.md#baseballstats) | **Get** /api/v1/baseballStats | List all baseball stats
*MiscAPI* | [**BroadcastAvailabilityTypes**](docs/MiscAPI.md#broadcastavailabilitytypes) | **Get** /api/v1/broadcastAvailability | View broadcast availability options
*MiscAPI* | [**CoachingVideoTypes**](docs/MiscAPI.md#coachingvideotypes) | **Get** /api/v1/coachingVideoTypes | List all coaching video types
*MiscAPI* | [**EventStatus**](docs/MiscAPI.md#eventstatus) | **Get** /api/v1/eventStatus | List all possible event status types
*MiscAPI* | [**EventTypes**](docs/MiscAPI.md#eventtypes) | **Get** /api/v1/eventTypes | List all event types
*MiscAPI* | [**FielderDetailTypes**](docs/MiscAPI.md#fielderdetailtypes) | **Get** /api/v1/fielderDetailTypes | List fielder detail types
*MiscAPI* | [**FreeGameTypes**](docs/MiscAPI.md#freegametypes) | **Get** /api/v1/freeGameTypes | View free game types
*MiscAPI* | [**GameStatus**](docs/MiscAPI.md#gamestatus) | **Get** /api/v1/gameStatus | List all status types
*MiscAPI* | [**GameTypes**](docs/MiscAPI.md#gametypes) | **Get** /api/v1/gameTypes | List all game types
*MiscAPI* | [**GamedayTypes**](docs/MiscAPI.md#gamedaytypes) | **Get** /api/v1/gamedayTypes | List all gameday types
*MiscAPI* | [**GetLookupValues**](docs/MiscAPI.md#getlookupvalues) | **Get** /api/v1/lookup/values/all | View all lookup values
*MiscAPI* | [**GroupByTypes**](docs/MiscAPI.md#groupbytypes) | **Get** /api/v1/groupByTypes | List groupBy types
*MiscAPI* | [**HitTrajectories**](docs/MiscAPI.md#hittrajectories) | **Get** /api/v1/hitTrajectories | List all hit trajectories
*MiscAPI* | [**JobTypes**](docs/MiscAPI.md#jobtypes) | **Get** /api/v1/jobTypes | List all job types
*MiscAPI* | [**Languages**](docs/MiscAPI.md#languages) | **Get** /api/v1/languages | List all support languages
*MiscAPI* | [**LeagueLeaderTypes**](docs/MiscAPI.md#leagueleadertypes) | **Get** /api/v1/leagueLeaderTypes | List all possible player league leader types
*MiscAPI* | [**LogicalEvents**](docs/MiscAPI.md#logicalevents) | **Get** /api/v1/logicalEvents | List all logical event types
*MiscAPI* | [**MediaStateTypes**](docs/MiscAPI.md#mediastatetypes) | **Get** /api/v1/mediaState | View media state options
*MiscAPI* | [**Metrics**](docs/MiscAPI.md#metrics) | **Get** /api/v1/metrics | List all possible metrics
*MiscAPI* | [**MoundVisitTypes**](docs/MiscAPI.md#moundvisittypes) | **Get** /api/v1/moundVisitTypes | List all mound visit types
*MiscAPI* | [**PerformerTypes**](docs/MiscAPI.md#performertypes) | **Get** /api/v1/performerTypes | List all possible performer types
*MiscAPI* | [**PitchCodes**](docs/MiscAPI.md#pitchcodes) | **Get** /api/v1/pitchCodes | List all pitch codes
*MiscAPI* | [**PitchTypes**](docs/MiscAPI.md#pitchtypes) | **Get** /api/v1/pitchTypes | List all pitch classification types
*MiscAPI* | [**Platforms**](docs/MiscAPI.md#platforms) | **Get** /api/v1/platforms | List all possible platforms
*MiscAPI* | [**PlayerStatusCodes**](docs/MiscAPI.md#playerstatuscodes) | **Get** /api/v1/playerStatusCodes | List all player status codes
*MiscAPI* | [**Positions**](docs/MiscAPI.md#positions) | **Get** /api/v1/positions | List all possible positions
*MiscAPI* | [**ReviewReasons**](docs/MiscAPI.md#reviewreasons) | **Get** /api/v1/reviewReasons | List all replay review reasons
*MiscAPI* | [**RoofTypes**](docs/MiscAPI.md#rooftypes) | **Get** /api/v1/roofTypes | List all roof types
*MiscAPI* | [**RosterTypes**](docs/MiscAPI.md#rostertypes) | **Get** /api/v1/rosterTypes | List all possible roster types
*MiscAPI* | [**RuleSettings**](docs/MiscAPI.md#rulesettings) | **Get** /api/v1/ruleSettings | List all ruleSettings
*MiscAPI* | [**RunnerDetailTypes**](docs/MiscAPI.md#runnerdetailtypes) | **Get** /api/v1/runnerDetailTypes | List runner detail types
*MiscAPI* | [**ScheduleEventTypes**](docs/MiscAPI.md#scheduleeventtypes) | **Get** /api/v1/scheduleEventTypes | List all schedule event types
*MiscAPI* | [**ScheduleTypes**](docs/MiscAPI.md#scheduletypes) | **Get** /api/v1/scheduleTypes | List all possible schedule types
*MiscAPI* | [**SitCodes**](docs/MiscAPI.md#sitcodes) | **Get** /api/v1/situationCodes | List all situation codes
*MiscAPI* | [**Sky**](docs/MiscAPI.md#sky) | **Get** /api/v1/sky | List all sky options
*MiscAPI* | [**StandingsTypes**](docs/MiscAPI.md#standingstypes) | **Get** /api/v1/standingsTypes | List all standings types
*MiscAPI* | [**StatFields**](docs/MiscAPI.md#statfields) | **Get** /api/v1/statFields | List all stat fields
*MiscAPI* | [**StatGroups**](docs/MiscAPI.md#statgroups) | **Get** /api/v1/statGroups | List all stat groups
*MiscAPI* | [**StatSearchConfig**](docs/MiscAPI.md#statsearchconfig) | **Get** /api/v1/stats/search/config | Stats Search Config Endpoint
*MiscAPI* | [**StatSearchGroupByTypes**](docs/MiscAPI.md#statsearchgroupbytypes) | **Get** /api/v1/stats/search/groupByTypes | List groupBy types
*MiscAPI* | [**StatSearchParams**](docs/MiscAPI.md#statsearchparams) | **Get** /api/v1/stats/search/params | List stat search parameters
*MiscAPI* | [**StatSearchStats**](docs/MiscAPI.md#statsearchstats) | **Get** /api/v1/stats/search/stats | List stat search stats
*MiscAPI* | [**StatTypes**](docs/MiscAPI.md#stattypes) | **Get** /api/v1/statTypes | List all stat types
*MiscAPI* | [**StatcastPositionTypes**](docs/MiscAPI.md#statcastpositiontypes) | **Get** /api/v1/statcastPositionTypes | List all statcast position types
*MiscAPI* | [**TrackingSoftwareVersions**](docs/MiscAPI.md#trackingsoftwareversions) | **Get** /api/v1/trackingSoftwareVersions | List the tracking software versions and notes
*MiscAPI* | [**TrackingSystemOwners**](docs/MiscAPI.md#trackingsystemowners) | **Get** /api/v1/trackingSystemOwners | List all tracking system owners
*MiscAPI* | [**TrackingVendors**](docs/MiscAPI.md#trackingvendors) | **Get** /api/v1/trackingVendors | List all tracking vendors
*MiscAPI* | [**TrackingVersions**](docs/MiscAPI.md#trackingversions) | **Get** /api/v1/trackingVersions | List all tracking versions
*MiscAPI* | [**TransactionTypes**](docs/MiscAPI.md#transactiontypes) | **Get** /api/v1/transactionTypes | List all transaction types
*MiscAPI* | [**UpdateGameStatuses**](docs/MiscAPI.md#updategamestatuses) | **Post** /api/v1/gameStatus | Clear all status types
*MiscAPI* | [**UpdateJobTypes**](docs/MiscAPI.md#updatejobtypes) | **Post** /api/v1/jobTypes | 
*MiscAPI* | [**VideoResolutionTypes**](docs/MiscAPI.md#videoresolutiontypes) | **Get** /api/v1/videoResolutionTypes | View video resolution options
*MiscAPI* | [**ViolationTypes**](docs/MiscAPI.md#violationtypes) | **Get** /api/v1/violationTypes | View available violationType options
*MiscAPI* | [**WeatherTrajectoryConfidences**](docs/MiscAPI.md#weathertrajectoryconfidences) | **Get** /api/v1/weatherTrajectoryConfidences | List all weather trajectories
*MiscAPI* | [**WindDirection**](docs/MiscAPI.md#winddirection) | **Get** /api/v1/windDirection | List all wind direction options
*PersonAPI* | [**Award**](docs/PersonAPI.md#award) | **Get** /api/v1/people/{personId}/awards | View a player&#39;s awards
*PersonAPI* | [**CurrentGameStats**](docs/PersonAPI.md#currentgamestats) | **Get** /api/v1/people/changes | View a player&#39;s change log
*PersonAPI* | [**FreeAgents**](docs/PersonAPI.md#freeagents) | **Get** /api/v1/people/freeAgents | Get free agents
*PersonAPI* | [**Person**](docs/PersonAPI.md#person) | **Get** /api/v1/people/{personId} | View a player
*PersonAPI* | [**Person1**](docs/PersonAPI.md#person1) | **Get** /api/v1/people | View a player
*PersonAPI* | [**PlayerGameStats**](docs/PersonAPI.md#playergamestats) | **Get** /api/v1/people/{personId}/stats/game/{gamePk} | View a player&#39;s game stats
*PersonAPI* | [**Search**](docs/PersonAPI.md#search) | **Get** /api/v1/people/search | Search for a player by name
*PersonAPI* | [**Stats3**](docs/PersonAPI.md#stats3) | **Get** /api/v1/people/{personId}/stats | View a players stats
*PersonAPI* | [**StatsMetrics**](docs/PersonAPI.md#statsmetrics) | **Get** /api/v1/people/{personId}/stats/metrics | View a player&#39;s stat metrics
*PredictionsAPI* | [**GetProps**](docs/PredictionsAPI.md#getprops) | **Get** /api/v1/props/play/predictions | Get play-level predictions based on input scenarios
*PredictionsAPI* | [**GetPropsAdjust**](docs/PredictionsAPI.md#getpropsadjust) | **Get** /api/v1/props/play/predictions/adjust | Get play-level predictions based on input scenarios
*ReviewsAPI* | [**GetReviewInfo**](docs/ReviewsAPI.md#getreviewinfo) | **Get** /api/v1/review | Get review info
*ScheduleAPI* | [**PostseasonSchedule**](docs/ScheduleAPI.md#postseasonschedule) | **Get** /api/v1/schedule/postseason | Get postseason schedule
*ScheduleAPI* | [**PostseasonScheduleSeries**](docs/ScheduleAPI.md#postseasonscheduleseries) | **Get** /api/v1/schedule/postseason/series | Get postseason series schedules
*ScheduleAPI* | [**Schedule**](docs/ScheduleAPI.md#schedule) | **Get** /api/v1/schedule | View schedule info based on scheduleType.
*ScheduleAPI* | [**Schedule1**](docs/ScheduleAPI.md#schedule1) | **Get** /api/v1/schedule/{scheduleType} | View schedule info based on scheduleType.
*ScheduleAPI* | [**TieGames**](docs/ScheduleAPI.md#tiegames) | **Get** /api/v1/schedule/games/tied | Get tied game schedules
*ScheduleAPI* | [**TrackingEventsSchedule**](docs/ScheduleAPI.md#trackingeventsschedule) | **Get** /api/v1/schedule/trackingEvents | Get tracking event schedules
*ScheduleAPI* | [**TuneIn**](docs/ScheduleAPI.md#tunein) | **Get** /api/v1/schedule/postseason/tuneIn | Get postseason TuneIn schedules
*SeasonAPI* | [**AllSeasons**](docs/SeasonAPI.md#allseasons) | **Get** /api/v1/seasons/all | View all seasons
*SeasonAPI* | [**Seasons**](docs/SeasonAPI.md#seasons) | **Get** /api/v1/seasons | View season info
*SeasonAPI* | [**Seasons1**](docs/SeasonAPI.md#seasons1) | **Get** /api/v1/seasons/{seasonId} | View season info
*SkeletalAPI* | [**SkeletalChunked**](docs/SkeletalAPI.md#skeletalchunked) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/skeletalData/chunked | View Skeletal Data by playId and gameId chunked
*SkeletalAPI* | [**SkeletalDataFileNames**](docs/SkeletalAPI.md#skeletaldatafilenames) | **Get** /api/v1/game/{gamePk}/{playId}/analytics/skeletalData/files | View Skeletal Data by playId and gameId files
*SportsAPI* | [**AllSportBallot**](docs/SportsAPI.md#allsportballot) | **Get** /api/v1/sports/{sportId}/allSportBallot | Get ALL MLB ballot for sport
*SportsAPI* | [**SportPlayers**](docs/SportsAPI.md#sportplayers) | **Get** /api/v1/sports/{sportId}/players | Get all players for a sport level
*SportsAPI* | [**Sports**](docs/SportsAPI.md#sports) | **Get** /api/v1/sports | Get sports information
*SportsAPI* | [**Sports1**](docs/SportsAPI.md#sports1) | **Get** /api/v1/sports/{sportId} | Get sports information
*StandingsAPI* | [**Standings**](docs/StandingsAPI.md#standings) | **Get** /api/v1/standings/{standingsType} | View standings for a league
*StandingsAPI* | [**Standings1**](docs/StandingsAPI.md#standings1) | **Get** /api/v1/standings | View standings for a league
*StatsAPI* | [**BeastStats**](docs/StatsAPI.md#beaststats) | **Get** /api/v1/stats/search | View stats from search
*StatsAPI* | [**GetOutsAboveAverage**](docs/StatsAPI.md#getoutsaboveaverage) | **Get** /api/v1/stats/analytics/outsAboveAverage | Get outs above average for the current batter
*StatsAPI* | [**GetSprayChart**](docs/StatsAPI.md#getspraychart) | **Get** /api/v1/stats/analytics/sprayChart | Get the spray chart info for the current batter
*StatsAPI* | [**GetStolenBaseProbability**](docs/StatsAPI.md#getstolenbaseprobability) | **Get** /api/v1/stats/analytics/stolenBaseProbability | Get the probability of a hit for the given hit data
*StatsAPI* | [**GroupedStats**](docs/StatsAPI.md#groupedstats) | **Get** /api/v1/stats/grouped | View grouped stats
*StatsAPI* | [**Leaders2**](docs/StatsAPI.md#leaders2) | **Get** /api/v1/stats/leaders | Get leaders for a statistic
*StatsAPI* | [**MetricStats**](docs/StatsAPI.md#metricstats) | **Get** /api/v1/stats/metrics | View metric stats
*StatsAPI* | [**Stats2**](docs/StatsAPI.md#stats2) | **Get** /api/v1/stats | View stats
*StreaksAPI* | [**GetStreaks**](docs/StreaksAPI.md#getstreaks) | **Get** /api/v1/streaks | View streaks
*StreaksAPI* | [**StreakTypes**](docs/StreaksAPI.md#streaktypes) | **Get** /api/v1/streaks/types | View streaks parameter options
*TeamsAPI* | [**Affiliates**](docs/TeamsAPI.md#affiliates) | **Get** /api/v1/teams/{teamId}/affiliates | View team and affiliate teams
*TeamsAPI* | [**Affiliates1**](docs/TeamsAPI.md#affiliates1) | **Get** /api/v1/teams/affiliates | View team and affiliate teams
*TeamsAPI* | [**AllTeams**](docs/TeamsAPI.md#allteams) | **Get** /api/v1/teams/{teamId}/history | View historical records for a list of teams
*TeamsAPI* | [**AllTeams1**](docs/TeamsAPI.md#allteams1) | **Get** /api/v1/teams/history | View historical records for a list of teams
*TeamsAPI* | [**Alumni**](docs/TeamsAPI.md#alumni) | **Get** /api/v1/teams/{teamId}/alumni | View all team alumni
*TeamsAPI* | [**Coaches**](docs/TeamsAPI.md#coaches) | **Get** /api/v1/teams/{teamId}/coaches | View all coaches for a team
*TeamsAPI* | [**Leaders**](docs/TeamsAPI.md#leaders) | **Get** /api/v1/teams/{teamId}/leaders | View team stat leaders
*TeamsAPI* | [**Leaders1**](docs/TeamsAPI.md#leaders1) | **Get** /api/v1/teams/stats/leaders | View leaders for team stats
*TeamsAPI* | [**Personnel**](docs/TeamsAPI.md#personnel) | **Get** /api/v1/teams/{teamId}/personnel | View all coaches for a team
*TeamsAPI* | [**Roster**](docs/TeamsAPI.md#roster) | **Get** /api/v1/teams/{teamId}/roster | View a teams roster
*TeamsAPI* | [**Roster1**](docs/TeamsAPI.md#roster1) | **Get** /api/v1/teams/{teamId}/roster/{rosterType} | View a teams roster
*TeamsAPI* | [**Stats**](docs/TeamsAPI.md#stats) | **Get** /api/v1/teams/{teamId}/stats | View a teams stats
*TeamsAPI* | [**Stats1**](docs/TeamsAPI.md#stats1) | **Get** /api/v1/teams/stats | View a teams stats
*TeamsAPI* | [**Teams**](docs/TeamsAPI.md#teams) | **Get** /api/v1/teams | View info for all teams
*TeamsAPI* | [**Teams1**](docs/TeamsAPI.md#teams1) | **Get** /api/v1/teams/{teamId} | View info for all teams
*TeamsAPI* | [**UpdateAlumni**](docs/TeamsAPI.md#updatealumni) | **Post** /api/v1/teams/{teamId}/alumni | 
*TransactionsAPI* | [**Transactions**](docs/TransactionsAPI.md#transactions) | **Get** /api/v1/transactions | View transaction info
*UniformsAPI* | [**UniformsByGame**](docs/UniformsAPI.md#uniformsbygame) | **Get** /api/v1/uniforms/game | View Game Uniform info
*UniformsAPI* | [**UniformsByTeam**](docs/UniformsAPI.md#uniformsbyteam) | **Get** /api/v1/uniforms/team | View Team Uniform info
*VenuesAPI* | [**Venues**](docs/VenuesAPI.md#venues) | **Get** /api/v1/venues | View venue info
*VenuesAPI* | [**Venues1**](docs/VenuesAPI.md#venues1) | **Get** /api/v1/venues/{venueId} | View venue info
*WeatherAPI* | [**WeatherBasic**](docs/WeatherAPI.md#weatherbasic) | **Get** /api/v1/weather/venues/{venueId}/basic | Get basic weather for a venue.
*WeatherAPI* | [**WeatherDataBasedOnPlay**](docs/WeatherAPI.md#weatherdatabasedonplay) | **Get** /api/v1/weather/game/{gamePk}/{playId} | Get the raw field weather data.
*WeatherAPI* | [**WeatherForecast**](docs/WeatherAPI.md#weatherforecast) | **Get** /api/v1/weather/game/{gamePk}/forecast/{roofType} | Get the weather forecast for a game.
*WeatherAPI* | [**WeatherFull**](docs/WeatherAPI.md#weatherfull) | **Get** /api/v1/weather/venues/{venueId}/full | Get full weather for a venue.


## Documentation For Models



## Documentation For Authorization

Endpoints do not require authorization.


## Documentation for Utility Methods

Due to the fact that model structure members are all pointers, this package contains
a number of utility functions to easily obtain pointers to values of basic types.
Each of these functions takes a value of the given basic type and returns a pointer to it:

* `PtrBool`
* `PtrInt`
* `PtrInt32`
* `PtrInt64`
* `PtrFloat`
* `PtrFloat32`
* `PtrFloat64`
* `PtrString`
* `PtrTime`

## Author



