/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
)

// AttendanceAPIService AttendanceAPI service
type AttendanceAPIService service

type ApiGetTeamAttendanceRequest struct {
	ctx          context.Context
	ApiService   *AttendanceAPIService
	teamId       *interface{}
	leagueId     *interface{}
	season       *interface{}
	leagueListId *interface{}
	gameType     *interface{}
	date         *interface{}
	startDate    *interface{}
	endDate      *interface{}
	fields       *interface{}
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiGetTeamAttendanceRequest) TeamId(teamId interface{}) ApiGetTeamAttendanceRequest {
	r.teamId = &teamId
	return r
}

// Comma delimited list of Unique league identifiers
func (r ApiGetTeamAttendanceRequest) LeagueId(leagueId interface{}) ApiGetTeamAttendanceRequest {
	r.leagueId = &leagueId
	return r
}

// Comma delimited list of Seasons of play
func (r ApiGetTeamAttendanceRequest) Season(season interface{}) ApiGetTeamAttendanceRequest {
	r.season = &season
	return r
}

// Unique League List Identifier
func (r ApiGetTeamAttendanceRequest) LeagueListId(leagueListId interface{}) ApiGetTeamAttendanceRequest {
	r.leagueListId = &leagueListId
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiGetTeamAttendanceRequest) GameType(gameType interface{}) ApiGetTeamAttendanceRequest {
	r.gameType = &gameType
	return r
}

// Date of Game. Format: YYYY-MM-DD
func (r ApiGetTeamAttendanceRequest) Date(date interface{}) ApiGetTeamAttendanceRequest {
	r.date = &date
	return r
}

// Start date for range of data (must be used with end date). Format: MM/DD/YYYY
func (r ApiGetTeamAttendanceRequest) StartDate(startDate interface{}) ApiGetTeamAttendanceRequest {
	r.startDate = &startDate
	return r
}

// End date for range of data (must be used with start date). Format: MM/DD/YYYY
func (r ApiGetTeamAttendanceRequest) EndDate(endDate interface{}) ApiGetTeamAttendanceRequest {
	r.endDate = &endDate
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiGetTeamAttendanceRequest) Fields(fields interface{}) ApiGetTeamAttendanceRequest {
	r.fields = &fields
	return r
}

func (r ApiGetTeamAttendanceRequest) Execute() (*http.Response, error) {
	return r.ApiService.GetTeamAttendanceExecute(r)
}

/*
GetTeamAttendance Get team attendance

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiGetTeamAttendanceRequest
*/
func (a *AttendanceAPIService) GetTeamAttendance(ctx context.Context) ApiGetTeamAttendanceRequest {
	return ApiGetTeamAttendanceRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *AttendanceAPIService) GetTeamAttendanceExecute(r ApiGetTeamAttendanceRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "AttendanceAPIService.GetTeamAttendance")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/attendance"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.leagueListId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueListId", r.leagueListId, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.date != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "date", r.date, "", "")
	}
	if r.startDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "startDate", r.startDate, "", "")
	}
	if r.endDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "endDate", r.endDate, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
