/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
	"strings"
)

// ConferenceAPIService ConferenceAPI service
type ConferenceAPIService service

type ApiConferencesRequest struct {
	ctx             context.Context
	ApiService      *ConferenceAPIService
	conferenceId    interface{}
	season          *interface{}
	includeInactive *interface{}
	fields          *interface{}
}

// Season of play
func (r ApiConferencesRequest) Season(season interface{}) ApiConferencesRequest {
	r.season = &season
	return r
}

func (r ApiConferencesRequest) IncludeInactive(includeInactive interface{}) ApiConferencesRequest {
	r.includeInactive = &includeInactive
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiConferencesRequest) Fields(fields interface{}) ApiConferencesRequest {
	r.fields = &fields
	return r
}

func (r ApiConferencesRequest) Execute() (*http.Response, error) {
	return r.ApiService.ConferencesExecute(r)
}

/*
Conferences View conference info

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param conferenceId
	@return ApiConferencesRequest
*/
func (a *ConferenceAPIService) Conferences(ctx context.Context, conferenceId interface{}) ApiConferencesRequest {
	return ApiConferencesRequest{
		ApiService:   a,
		ctx:          ctx,
		conferenceId: conferenceId,
	}
}

// Execute executes the request
func (a *ConferenceAPIService) ConferencesExecute(r ApiConferencesRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ConferenceAPIService.Conferences")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/conferences"
	localVarPath = strings.Replace(localVarPath, "{"+"conferenceId"+"}", url.PathEscape(parameterValueToString(r.conferenceId, "conferenceId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.includeInactive != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeInactive", r.includeInactive, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiConferences1Request struct {
	ctx             context.Context
	ApiService      *ConferenceAPIService
	conferenceId    interface{}
	season          *interface{}
	includeInactive *interface{}
	fields          *interface{}
}

// Season of play
func (r ApiConferences1Request) Season(season interface{}) ApiConferences1Request {
	r.season = &season
	return r
}

func (r ApiConferences1Request) IncludeInactive(includeInactive interface{}) ApiConferences1Request {
	r.includeInactive = &includeInactive
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiConferences1Request) Fields(fields interface{}) ApiConferences1Request {
	r.fields = &fields
	return r
}

func (r ApiConferences1Request) Execute() (*http.Response, error) {
	return r.ApiService.Conferences1Execute(r)
}

/*
Conferences1 View conference info

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param conferenceId
	@return ApiConferences1Request
*/
func (a *ConferenceAPIService) Conferences1(ctx context.Context, conferenceId interface{}) ApiConferences1Request {
	return ApiConferences1Request{
		ApiService:   a,
		ctx:          ctx,
		conferenceId: conferenceId,
	}
}

// Execute executes the request
func (a *ConferenceAPIService) Conferences1Execute(r ApiConferences1Request) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ConferenceAPIService.Conferences1")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/conferences/{conferenceId}"
	localVarPath = strings.Replace(localVarPath, "{"+"conferenceId"+"}", url.PathEscape(parameterValueToString(r.conferenceId, "conferenceId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.includeInactive != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeInactive", r.includeInactive, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
