/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
	"strings"
)

// DivisionAPIService DivisionAPI service
type DivisionAPIService service

type ApiDivisionsRequest struct {
	ctx             context.Context
	ApiService      *DivisionAPIService
	divisionId      interface{}
	includeInactive *interface{}
	leagueId        *interface{}
	sportId         *interface{}
	season          *interface{}
	fields          *interface{}
}

// Whether or not to include inactive
func (r ApiDivisionsRequest) IncludeInactive(includeInactive interface{}) ApiDivisionsRequest {
	r.includeInactive = &includeInactive
	return r
}

// Unique League Identifier
func (r ApiDivisionsRequest) LeagueId(leagueId interface{}) ApiDivisionsRequest {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiDivisionsRequest) SportId(sportId interface{}) ApiDivisionsRequest {
	r.sportId = &sportId
	return r
}

// Season of play
func (r ApiDivisionsRequest) Season(season interface{}) ApiDivisionsRequest {
	r.season = &season
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiDivisionsRequest) Fields(fields interface{}) ApiDivisionsRequest {
	r.fields = &fields
	return r
}

func (r ApiDivisionsRequest) Execute() (*http.Response, error) {
	return r.ApiService.DivisionsExecute(r)
}

/*
Divisions Get division information

This endpoint allows you to pull divisions

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param divisionId Unique Division Identifier
	@return ApiDivisionsRequest
*/
func (a *DivisionAPIService) Divisions(ctx context.Context, divisionId interface{}) ApiDivisionsRequest {
	return ApiDivisionsRequest{
		ApiService: a,
		ctx:        ctx,
		divisionId: divisionId,
	}
}

// Execute executes the request
func (a *DivisionAPIService) DivisionsExecute(r ApiDivisionsRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "DivisionAPIService.Divisions")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/divisions"
	localVarPath = strings.Replace(localVarPath, "{"+"divisionId"+"}", url.PathEscape(parameterValueToString(r.divisionId, "divisionId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.includeInactive != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeInactive", r.includeInactive, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiDivisions1Request struct {
	ctx             context.Context
	ApiService      *DivisionAPIService
	divisionId      interface{}
	includeInactive *interface{}
	leagueId        *interface{}
	sportId         *interface{}
	season          *interface{}
	fields          *interface{}
}

// Whether or not to include inactive
func (r ApiDivisions1Request) IncludeInactive(includeInactive interface{}) ApiDivisions1Request {
	r.includeInactive = &includeInactive
	return r
}

// Unique League Identifier
func (r ApiDivisions1Request) LeagueId(leagueId interface{}) ApiDivisions1Request {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiDivisions1Request) SportId(sportId interface{}) ApiDivisions1Request {
	r.sportId = &sportId
	return r
}

// Season of play
func (r ApiDivisions1Request) Season(season interface{}) ApiDivisions1Request {
	r.season = &season
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiDivisions1Request) Fields(fields interface{}) ApiDivisions1Request {
	r.fields = &fields
	return r
}

func (r ApiDivisions1Request) Execute() (*http.Response, error) {
	return r.ApiService.Divisions1Execute(r)
}

/*
Divisions1 Get division information

This endpoint allows you to pull divisions

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param divisionId Unique Division Identifier
	@return ApiDivisions1Request
*/
func (a *DivisionAPIService) Divisions1(ctx context.Context, divisionId interface{}) ApiDivisions1Request {
	return ApiDivisions1Request{
		ApiService: a,
		ctx:        ctx,
		divisionId: divisionId,
	}
}

// Execute executes the request
func (a *DivisionAPIService) Divisions1Execute(r ApiDivisions1Request) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "DivisionAPIService.Divisions1")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/divisions/{divisionId}"
	localVarPath = strings.Replace(localVarPath, "{"+"divisionId"+"}", url.PathEscape(parameterValueToString(r.divisionId, "divisionId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.includeInactive != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeInactive", r.includeInactive, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
