/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
	"strings"
)

// HighLowAPIService HighLowAPI service
type HighLowAPIService service

type ApiHighLowRequest struct {
	ctx         context.Context
	ApiService  *HighLowAPIService
	highLowType interface{}
	statGroup   *interface{}
	sortStat    *interface{}
	season      *interface{}
	gameType    *interface{}
	teamId      *interface{}
	leagueId    *interface{}
	sportId     *interface{}
	offset      *interface{}
	limit       *interface{}
	fields      *interface{}
}

// Comma delimited list of  categories of statistic to return. Available types in /api/v1/statGroups
func (r ApiHighLowRequest) StatGroup(statGroup interface{}) ApiHighLowRequest {
	r.statGroup = &statGroup
	return r
}

// Comma delimited list of baseball stats to sort splits by.
func (r ApiHighLowRequest) SortStat(sortStat interface{}) ApiHighLowRequest {
	r.sortStat = &sortStat
	return r
}

// Comma delimited list of Seasons of play
func (r ApiHighLowRequest) Season(season interface{}) ApiHighLowRequest {
	r.season = &season
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiHighLowRequest) GameType(gameType interface{}) ApiHighLowRequest {
	r.gameType = &gameType
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiHighLowRequest) TeamId(teamId interface{}) ApiHighLowRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiHighLowRequest) LeagueId(leagueId interface{}) ApiHighLowRequest {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiHighLowRequest) SportId(sportId interface{}) ApiHighLowRequest {
	r.sportId = &sportId
	return r
}

// The pointer to start for a return set; used for pagination
func (r ApiHighLowRequest) Offset(offset interface{}) ApiHighLowRequest {
	r.offset = &offset
	return r
}

// Number of results to return
func (r ApiHighLowRequest) Limit(limit interface{}) ApiHighLowRequest {
	r.limit = &limit
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiHighLowRequest) Fields(fields interface{}) ApiHighLowRequest {
	r.fields = &fields
	return r
}

func (r ApiHighLowRequest) Execute() (*http.Response, error) {
	return r.ApiService.HighLowExecute(r)
}

/*
HighLow View high/low stats by player or team

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param highLowType Type of high/low stats ('player', 'team', 'game')
	@return ApiHighLowRequest
*/
func (a *HighLowAPIService) HighLow(ctx context.Context, highLowType interface{}) ApiHighLowRequest {
	return ApiHighLowRequest{
		ApiService:  a,
		ctx:         ctx,
		highLowType: highLowType,
	}
}

// Execute executes the request
func (a *HighLowAPIService) HighLowExecute(r ApiHighLowRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "HighLowAPIService.HighLow")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/highLow/{highLowType}"
	localVarPath = strings.Replace(localVarPath, "{"+"highLowType"+"}", url.PathEscape(parameterValueToString(r.highLowType, "highLowType")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.statGroup != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "statGroup", r.statGroup, "", "")
	}
	if r.sortStat != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sortStat", r.sortStat, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.offset != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "offset", r.offset, "", "")
	}
	if r.limit != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "limit", r.limit, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiHighLowStatsRequest struct {
	ctx        context.Context
	ApiService *HighLowAPIService
}

func (r ApiHighLowStatsRequest) Execute() (*http.Response, error) {
	return r.ApiService.HighLowStatsExecute(r)
}

/*
HighLowStats View high/low stat types

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiHighLowStatsRequest
*/
func (a *HighLowAPIService) HighLowStats(ctx context.Context) ApiHighLowStatsRequest {
	return ApiHighLowStatsRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *HighLowAPIService) HighLowStatsExecute(r ApiHighLowStatsRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "HighLowAPIService.HighLowStats")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/highLow/types"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
