/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
)

// PredictionsAPIService PredictionsAPI service
type PredictionsAPIService service

type ApiGetPropsRequest struct {
	ctx             context.Context
	ApiService      *PredictionsAPIService
	batterId        *interface{}
	pitcherId       *interface{}
	venueId         *interface{}
	batSide         *interface{}
	pitchHand       *interface{}
	batterPosition  *interface{}
	pitcherPosition *interface{}
}

// Unique Player Identifier. Format: 434538, 429665, etc
func (r ApiGetPropsRequest) BatterId(batterId interface{}) ApiGetPropsRequest {
	r.batterId = &batterId
	return r
}

// Unique Player Identifier. Format: 434538, 429665, etc
func (r ApiGetPropsRequest) PitcherId(pitcherId interface{}) ApiGetPropsRequest {
	r.pitcherId = &pitcherId
	return r
}

// Unique Venue Identifier
func (r ApiGetPropsRequest) VenueId(venueId interface{}) ApiGetPropsRequest {
	r.venueId = &venueId
	return r
}

// Bat side of hitter
func (r ApiGetPropsRequest) BatSide(batSide interface{}) ApiGetPropsRequest {
	r.batSide = &batSide
	return r
}

// Handedness of pitcher
func (r ApiGetPropsRequest) PitchHand(pitchHand interface{}) ApiGetPropsRequest {
	r.pitchHand = &pitchHand
	return r
}

// Position abbreviation. Format: SS, P, 1B, etc
func (r ApiGetPropsRequest) BatterPosition(batterPosition interface{}) ApiGetPropsRequest {
	r.batterPosition = &batterPosition
	return r
}

// Position abbreviation. Format: SS, P, 1B, etc
func (r ApiGetPropsRequest) PitcherPosition(pitcherPosition interface{}) ApiGetPropsRequest {
	r.pitcherPosition = &pitcherPosition
	return r
}

func (r ApiGetPropsRequest) Execute() (*http.Response, error) {
	return r.ApiService.GetPropsExecute(r)
}

/*
GetProps Get play-level predictions based on input scenarios

This endpoint allows you to get play-level predictions based on input scenarios

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiGetPropsRequest
*/
func (a *PredictionsAPIService) GetProps(ctx context.Context) ApiGetPropsRequest {
	return ApiGetPropsRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *PredictionsAPIService) GetPropsExecute(r ApiGetPropsRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "PredictionsAPIService.GetProps")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/props/play/predictions"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.batterId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "batterId", r.batterId, "", "")
	}
	if r.pitcherId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "pitcherId", r.pitcherId, "", "")
	}
	if r.venueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueId", r.venueId, "", "")
	}
	if r.batSide != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "batSide", r.batSide, "", "")
	}
	if r.pitchHand != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "pitchHand", r.pitchHand, "", "")
	}
	if r.batterPosition != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "batterPosition", r.batterPosition, "", "")
	}
	if r.pitcherPosition != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "pitcherPosition", r.pitcherPosition, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiGetPropsAdjustRequest struct {
	ctx        context.Context
	ApiService *PredictionsAPIService
	gamePk     *interface{}
}

// Unique Primary Key Representing a Game
func (r ApiGetPropsAdjustRequest) GamePk(gamePk interface{}) ApiGetPropsAdjustRequest {
	r.gamePk = &gamePk
	return r
}

func (r ApiGetPropsAdjustRequest) Execute() (*http.Response, error) {
	return r.ApiService.GetPropsAdjustExecute(r)
}

/*
GetPropsAdjust Get play-level predictions based on input scenarios

This endpoint allows you to get play-level predictions based on input scenarios

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiGetPropsAdjustRequest
*/
func (a *PredictionsAPIService) GetPropsAdjust(ctx context.Context) ApiGetPropsAdjustRequest {
	return ApiGetPropsAdjustRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *PredictionsAPIService) GetPropsAdjustExecute(r ApiGetPropsAdjustRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "PredictionsAPIService.GetPropsAdjust")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/props/play/predictions/adjust"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.gamePk == nil {
		return nil, reportError("gamePk is required and must be specified")
	}

	parameterAddToHeaderOrQuery(localVarQueryParams, "gamePk", r.gamePk, "", "")
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
