/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
)

// ReviewsAPIService ReviewsAPI service
type ReviewsAPIService service

type ApiGetReviewInfoRequest struct {
	ctx        context.Context
	ApiService *ReviewsAPIService
	sportId    *interface{}
	season     *interface{}
	gameType   *interface{}
	fields     *interface{}
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiGetReviewInfoRequest) SportId(sportId interface{}) ApiGetReviewInfoRequest {
	r.sportId = &sportId
	return r
}

// Comma delimited list of Seasons of play
func (r ApiGetReviewInfoRequest) Season(season interface{}) ApiGetReviewInfoRequest {
	r.season = &season
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiGetReviewInfoRequest) GameType(gameType interface{}) ApiGetReviewInfoRequest {
	r.gameType = &gameType
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiGetReviewInfoRequest) Fields(fields interface{}) ApiGetReviewInfoRequest {
	r.fields = &fields
	return r
}

func (r ApiGetReviewInfoRequest) Execute() (*http.Response, error) {
	return r.ApiService.GetReviewInfoExecute(r)
}

/*
GetReviewInfo Get review info

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiGetReviewInfoRequest
*/
func (a *ReviewsAPIService) GetReviewInfo(ctx context.Context) ApiGetReviewInfoRequest {
	return ApiGetReviewInfoRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ReviewsAPIService) GetReviewInfoExecute(r ApiGetReviewInfoRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ReviewsAPIService.GetReviewInfo")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/review"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.sportId == nil {
		return nil, reportError("sportId is required and must be specified")
	}
	if r.season == nil {
		return nil, reportError("season is required and must be specified")
	}

	parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
