/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
)

// ScheduleAPIService ScheduleAPI service
type ScheduleAPIService service

type ApiPostseasonScheduleRequest struct {
	ctx             context.Context
	ApiService      *ScheduleAPIService
	gameTypes       *interface{}
	seriesNumber    *interface{}
	teamId          *interface{}
	sportId         *interface{}
	useLatestGames  *interface{}
	useFeaturedGame *interface{}
	season          *interface{}
	publicFacing    *interface{}
	fields          *interface{}
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiPostseasonScheduleRequest) GameTypes(gameTypes interface{}) ApiPostseasonScheduleRequest {
	r.gameTypes = &gameTypes
	return r
}

func (r ApiPostseasonScheduleRequest) SeriesNumber(seriesNumber interface{}) ApiPostseasonScheduleRequest {
	r.seriesNumber = &seriesNumber
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiPostseasonScheduleRequest) TeamId(teamId interface{}) ApiPostseasonScheduleRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiPostseasonScheduleRequest) SportId(sportId interface{}) ApiPostseasonScheduleRequest {
	r.sportId = &sportId
	return r
}

func (r ApiPostseasonScheduleRequest) UseLatestGames(useLatestGames interface{}) ApiPostseasonScheduleRequest {
	r.useLatestGames = &useLatestGames
	return r
}

func (r ApiPostseasonScheduleRequest) UseFeaturedGame(useFeaturedGame interface{}) ApiPostseasonScheduleRequest {
	r.useFeaturedGame = &useFeaturedGame
	return r
}

func (r ApiPostseasonScheduleRequest) Season(season interface{}) ApiPostseasonScheduleRequest {
	r.season = &season
	return r
}

// Return public, non-public or all games. Format: Public Facing &#x3D; &#39;Y&#39;, Non-Public Facing &#x3D; &#39;N&#39;, All &#x3D; &#39;A&#39;
func (r ApiPostseasonScheduleRequest) PublicFacing(publicFacing interface{}) ApiPostseasonScheduleRequest {
	r.publicFacing = &publicFacing
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiPostseasonScheduleRequest) Fields(fields interface{}) ApiPostseasonScheduleRequest {
	r.fields = &fields
	return r
}

func (r ApiPostseasonScheduleRequest) Execute() (*http.Response, error) {
	return r.ApiService.PostseasonScheduleExecute(r)
}

/*
PostseasonSchedule Get postseason schedule

This endpoint allows you to pull postseason schedules

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiPostseasonScheduleRequest
*/
func (a *ScheduleAPIService) PostseasonSchedule(ctx context.Context) ApiPostseasonScheduleRequest {
	return ApiPostseasonScheduleRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) PostseasonScheduleExecute(r ApiPostseasonScheduleRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.PostseasonSchedule")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/postseason"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.seriesNumber != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seriesNumber", r.seriesNumber, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.useLatestGames != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useLatestGames", r.useLatestGames, "", "")
	}
	if r.useFeaturedGame != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useFeaturedGame", r.useFeaturedGame, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.publicFacing != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "publicFacing", r.publicFacing, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiPostseasonScheduleSeriesRequest struct {
	ctx             context.Context
	ApiService      *ScheduleAPIService
	gameTypes       *interface{}
	seriesNumber    *interface{}
	teamId          *interface{}
	sportId         *interface{}
	date            *interface{}
	startDate       *interface{}
	endDate         *interface{}
	useLatestGames  *interface{}
	useFeaturedGame *interface{}
	season          *interface{}
	fields          *interface{}
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiPostseasonScheduleSeriesRequest) GameTypes(gameTypes interface{}) ApiPostseasonScheduleSeriesRequest {
	r.gameTypes = &gameTypes
	return r
}

func (r ApiPostseasonScheduleSeriesRequest) SeriesNumber(seriesNumber interface{}) ApiPostseasonScheduleSeriesRequest {
	r.seriesNumber = &seriesNumber
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiPostseasonScheduleSeriesRequest) TeamId(teamId interface{}) ApiPostseasonScheduleSeriesRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiPostseasonScheduleSeriesRequest) SportId(sportId interface{}) ApiPostseasonScheduleSeriesRequest {
	r.sportId = &sportId
	return r
}

// Date of Game. Format: YYYY-MM-DD
func (r ApiPostseasonScheduleSeriesRequest) Date(date interface{}) ApiPostseasonScheduleSeriesRequest {
	r.date = &date
	return r
}

// Start date for range of data (must be used with end date). Format: MM/DD/YYYY
func (r ApiPostseasonScheduleSeriesRequest) StartDate(startDate interface{}) ApiPostseasonScheduleSeriesRequest {
	r.startDate = &startDate
	return r
}

// End date for range of data (must be used with start date). Format: MM/DD/YYYY
func (r ApiPostseasonScheduleSeriesRequest) EndDate(endDate interface{}) ApiPostseasonScheduleSeriesRequest {
	r.endDate = &endDate
	return r
}

func (r ApiPostseasonScheduleSeriesRequest) UseLatestGames(useLatestGames interface{}) ApiPostseasonScheduleSeriesRequest {
	r.useLatestGames = &useLatestGames
	return r
}

func (r ApiPostseasonScheduleSeriesRequest) UseFeaturedGame(useFeaturedGame interface{}) ApiPostseasonScheduleSeriesRequest {
	r.useFeaturedGame = &useFeaturedGame
	return r
}

func (r ApiPostseasonScheduleSeriesRequest) Season(season interface{}) ApiPostseasonScheduleSeriesRequest {
	r.season = &season
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiPostseasonScheduleSeriesRequest) Fields(fields interface{}) ApiPostseasonScheduleSeriesRequest {
	r.fields = &fields
	return r
}

func (r ApiPostseasonScheduleSeriesRequest) Execute() (*http.Response, error) {
	return r.ApiService.PostseasonScheduleSeriesExecute(r)
}

/*
PostseasonScheduleSeries Get postseason series schedules

This endpoint allows you to pull postseason schedules

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiPostseasonScheduleSeriesRequest
*/
func (a *ScheduleAPIService) PostseasonScheduleSeries(ctx context.Context) ApiPostseasonScheduleSeriesRequest {
	return ApiPostseasonScheduleSeriesRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) PostseasonScheduleSeriesExecute(r ApiPostseasonScheduleSeriesRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.PostseasonScheduleSeries")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/postseason/series"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.seriesNumber != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seriesNumber", r.seriesNumber, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.date != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "date", r.date, "", "")
	}
	if r.startDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "startDate", r.startDate, "", "")
	}
	if r.endDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "endDate", r.endDate, "", "")
	}
	if r.useLatestGames != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useLatestGames", r.useLatestGames, "", "")
	}
	if r.useFeaturedGame != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useFeaturedGame", r.useFeaturedGame, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiScheduleRequest struct {
	ctx                  context.Context
	ApiService           *ScheduleAPIService
	usingPrivateEndpoint *interface{}
	calendarTypes        *interface{}
	eventTypes           *interface{}
	scheduleEventTypes   *interface{}
	teamId               *interface{}
	leagueId             *interface{}
	sportId              *interface{}
	gamePk               *interface{}
	gamePks              *interface{}
	eventIds             *interface{}
	venueIds             *interface{}
	performerIds         *interface{}
	gameTypes            *interface{}
	gameType             *interface{}
	season               *interface{}
	seasons              *interface{}
	date                 *interface{}
	startDate            *interface{}
	endDate              *interface{}
	timecode             *interface{}
	useLatestGames       *interface{}
	opponentId           *interface{}
	publicFacing         *interface{}
	fields               *interface{}
}

func (r ApiScheduleRequest) UsingPrivateEndpoint(usingPrivateEndpoint interface{}) ApiScheduleRequest {
	r.usingPrivateEndpoint = &usingPrivateEndpoint
	return r
}

// Comma delimited list of type of calendar types
func (r ApiScheduleRequest) CalendarTypes(calendarTypes interface{}) ApiScheduleRequest {
	r.calendarTypes = &calendarTypes
	return r
}

// Comma delimited list of type of events. &lt;b&gt;Note: Don&#39;t Use. This will be deprecated in favor of calendarTypes&lt;/b&gt;
func (r ApiScheduleRequest) EventTypes(eventTypes interface{}) ApiScheduleRequest {
	r.eventTypes = &eventTypes
	return r
}

// Comma delimited list of type of event types
func (r ApiScheduleRequest) ScheduleEventTypes(scheduleEventTypes interface{}) ApiScheduleRequest {
	r.scheduleEventTypes = &scheduleEventTypes
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiScheduleRequest) TeamId(teamId interface{}) ApiScheduleRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiScheduleRequest) LeagueId(leagueId interface{}) ApiScheduleRequest {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiScheduleRequest) SportId(sportId interface{}) ApiScheduleRequest {
	r.sportId = &sportId
	return r
}

// Unique Primary Key Representing a Game
func (r ApiScheduleRequest) GamePk(gamePk interface{}) ApiScheduleRequest {
	r.gamePk = &gamePk
	return r
}

// Comma delimited list of unique primary keys
func (r ApiScheduleRequest) GamePks(gamePks interface{}) ApiScheduleRequest {
	r.gamePks = &gamePks
	return r
}

// A unique identifier for non-game event
func (r ApiScheduleRequest) EventIds(eventIds interface{}) ApiScheduleRequest {
	r.eventIds = &eventIds
	return r
}

// Unique Venue Identifier
func (r ApiScheduleRequest) VenueIds(venueIds interface{}) ApiScheduleRequest {
	r.venueIds = &venueIds
	return r
}

// A unique identifier for non-team event performers
func (r ApiScheduleRequest) PerformerIds(performerIds interface{}) ApiScheduleRequest {
	r.performerIds = &performerIds
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiScheduleRequest) GameTypes(gameTypes interface{}) ApiScheduleRequest {
	r.gameTypes = &gameTypes
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiScheduleRequest) GameType(gameType interface{}) ApiScheduleRequest {
	r.gameType = &gameType
	return r
}

// Season of play
func (r ApiScheduleRequest) Season(season interface{}) ApiScheduleRequest {
	r.season = &season
	return r
}

// Comma delimited list of Seasons of play
func (r ApiScheduleRequest) Seasons(seasons interface{}) ApiScheduleRequest {
	r.seasons = &seasons
	return r
}

// Date of Game. Format: YYYY-MM-DD
func (r ApiScheduleRequest) Date(date interface{}) ApiScheduleRequest {
	r.date = &date
	return r
}

// Start date for range of data (must be used with end date). Format: MM/DD/YYYY
func (r ApiScheduleRequest) StartDate(startDate interface{}) ApiScheduleRequest {
	r.startDate = &startDate
	return r
}

// End date for range of data (must be used with start date). Format: MM/DD/YYYY
func (r ApiScheduleRequest) EndDate(endDate interface{}) ApiScheduleRequest {
	r.endDate = &endDate
	return r
}

// Use this parameter to return a snapshot of the data at the specified time. Format: YYYYMMDD_HHMMSS
func (r ApiScheduleRequest) Timecode(timecode interface{}) ApiScheduleRequest {
	r.timecode = &timecode
	return r
}

func (r ApiScheduleRequest) UseLatestGames(useLatestGames interface{}) ApiScheduleRequest {
	r.useLatestGames = &useLatestGames
	return r
}

// A unique identifier for the opposing team. Must be used with Team ID
func (r ApiScheduleRequest) OpponentId(opponentId interface{}) ApiScheduleRequest {
	r.opponentId = &opponentId
	return r
}

// Return public, non-public or all games. Format: Public Facing &#x3D; &#39;Y&#39;, Non-Public Facing &#x3D; &#39;N&#39;, All &#x3D; &#39;A&#39;
func (r ApiScheduleRequest) PublicFacing(publicFacing interface{}) ApiScheduleRequest {
	r.publicFacing = &publicFacing
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiScheduleRequest) Fields(fields interface{}) ApiScheduleRequest {
	r.fields = &fields
	return r
}

func (r ApiScheduleRequest) Execute() (*http.Response, error) {
	return r.ApiService.ScheduleExecute(r)
}

/*
Schedule View schedule info based on scheduleType.

View schedule info. This endpoint allows you to pull schedules

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiScheduleRequest
*/
func (a *ScheduleAPIService) Schedule(ctx context.Context) ApiScheduleRequest {
	return ApiScheduleRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) ScheduleExecute(r ApiScheduleRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.Schedule")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.usingPrivateEndpoint == nil {
		return nil, reportError("usingPrivateEndpoint is required and must be specified")
	}

	if r.calendarTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "calendarTypes", r.calendarTypes, "", "")
	}
	if r.eventTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventTypes", r.eventTypes, "", "")
	}
	if r.scheduleEventTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "scheduleEventTypes", r.scheduleEventTypes, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.gamePk != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePk", r.gamePk, "", "")
	}
	if r.gamePks != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePks", r.gamePks, "", "")
	}
	if r.eventIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventIds", r.eventIds, "", "")
	}
	if r.venueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueIds", r.venueIds, "", "")
	}
	if r.performerIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "performerIds", r.performerIds, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.seasons != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seasons", r.seasons, "", "")
	}
	if r.date != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "date", r.date, "", "")
	}
	if r.startDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "startDate", r.startDate, "", "")
	}
	if r.endDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "endDate", r.endDate, "", "")
	}
	if r.timecode != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "timecode", r.timecode, "", "")
	}
	if r.useLatestGames != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useLatestGames", r.useLatestGames, "", "")
	}
	if r.opponentId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "opponentId", r.opponentId, "", "")
	}
	if r.publicFacing != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "publicFacing", r.publicFacing, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	parameterAddToHeaderOrQuery(localVarQueryParams, "usingPrivateEndpoint", r.usingPrivateEndpoint, "", "")
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiSchedule1Request struct {
	ctx                  context.Context
	ApiService           *ScheduleAPIService
	usingPrivateEndpoint *interface{}
	calendarTypes        *interface{}
	eventTypes           *interface{}
	scheduleEventTypes   *interface{}
	teamId               *interface{}
	leagueId             *interface{}
	sportId              *interface{}
	gamePk               *interface{}
	gamePks              *interface{}
	eventIds             *interface{}
	venueIds             *interface{}
	performerIds         *interface{}
	gameTypes            *interface{}
	gameType             *interface{}
	season               *interface{}
	seasons              *interface{}
	date                 *interface{}
	startDate            *interface{}
	endDate              *interface{}
	timecode             *interface{}
	useLatestGames       *interface{}
	opponentId           *interface{}
	publicFacing         *interface{}
	fields               *interface{}
}

func (r ApiSchedule1Request) UsingPrivateEndpoint(usingPrivateEndpoint interface{}) ApiSchedule1Request {
	r.usingPrivateEndpoint = &usingPrivateEndpoint
	return r
}

// Comma delimited list of type of calendar types
func (r ApiSchedule1Request) CalendarTypes(calendarTypes interface{}) ApiSchedule1Request {
	r.calendarTypes = &calendarTypes
	return r
}

// Comma delimited list of type of events. &lt;b&gt;Note: Don&#39;t Use. This will be deprecated in favor of calendarTypes&lt;/b&gt;
func (r ApiSchedule1Request) EventTypes(eventTypes interface{}) ApiSchedule1Request {
	r.eventTypes = &eventTypes
	return r
}

// Comma delimited list of type of event types
func (r ApiSchedule1Request) ScheduleEventTypes(scheduleEventTypes interface{}) ApiSchedule1Request {
	r.scheduleEventTypes = &scheduleEventTypes
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiSchedule1Request) TeamId(teamId interface{}) ApiSchedule1Request {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiSchedule1Request) LeagueId(leagueId interface{}) ApiSchedule1Request {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiSchedule1Request) SportId(sportId interface{}) ApiSchedule1Request {
	r.sportId = &sportId
	return r
}

// Unique Primary Key Representing a Game
func (r ApiSchedule1Request) GamePk(gamePk interface{}) ApiSchedule1Request {
	r.gamePk = &gamePk
	return r
}

// Comma delimited list of unique primary keys
func (r ApiSchedule1Request) GamePks(gamePks interface{}) ApiSchedule1Request {
	r.gamePks = &gamePks
	return r
}

// A unique identifier for non-game event
func (r ApiSchedule1Request) EventIds(eventIds interface{}) ApiSchedule1Request {
	r.eventIds = &eventIds
	return r
}

// Unique Venue Identifier
func (r ApiSchedule1Request) VenueIds(venueIds interface{}) ApiSchedule1Request {
	r.venueIds = &venueIds
	return r
}

// A unique identifier for non-team event performers
func (r ApiSchedule1Request) PerformerIds(performerIds interface{}) ApiSchedule1Request {
	r.performerIds = &performerIds
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiSchedule1Request) GameTypes(gameTypes interface{}) ApiSchedule1Request {
	r.gameTypes = &gameTypes
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiSchedule1Request) GameType(gameType interface{}) ApiSchedule1Request {
	r.gameType = &gameType
	return r
}

// Season of play
func (r ApiSchedule1Request) Season(season interface{}) ApiSchedule1Request {
	r.season = &season
	return r
}

// Comma delimited list of Seasons of play
func (r ApiSchedule1Request) Seasons(seasons interface{}) ApiSchedule1Request {
	r.seasons = &seasons
	return r
}

// Date of Game. Format: YYYY-MM-DD
func (r ApiSchedule1Request) Date(date interface{}) ApiSchedule1Request {
	r.date = &date
	return r
}

// Start date for range of data (must be used with end date). Format: MM/DD/YYYY
func (r ApiSchedule1Request) StartDate(startDate interface{}) ApiSchedule1Request {
	r.startDate = &startDate
	return r
}

// End date for range of data (must be used with start date). Format: MM/DD/YYYY
func (r ApiSchedule1Request) EndDate(endDate interface{}) ApiSchedule1Request {
	r.endDate = &endDate
	return r
}

// Use this parameter to return a snapshot of the data at the specified time. Format: YYYYMMDD_HHMMSS
func (r ApiSchedule1Request) Timecode(timecode interface{}) ApiSchedule1Request {
	r.timecode = &timecode
	return r
}

func (r ApiSchedule1Request) UseLatestGames(useLatestGames interface{}) ApiSchedule1Request {
	r.useLatestGames = &useLatestGames
	return r
}

// A unique identifier for the opposing team. Must be used with Team ID
func (r ApiSchedule1Request) OpponentId(opponentId interface{}) ApiSchedule1Request {
	r.opponentId = &opponentId
	return r
}

// Return public, non-public or all games. Format: Public Facing &#x3D; &#39;Y&#39;, Non-Public Facing &#x3D; &#39;N&#39;, All &#x3D; &#39;A&#39;
func (r ApiSchedule1Request) PublicFacing(publicFacing interface{}) ApiSchedule1Request {
	r.publicFacing = &publicFacing
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiSchedule1Request) Fields(fields interface{}) ApiSchedule1Request {
	r.fields = &fields
	return r
}

func (r ApiSchedule1Request) Execute() (*http.Response, error) {
	return r.ApiService.Schedule1Execute(r)
}

/*
Schedule1 View schedule info based on scheduleType.

View schedule info. This endpoint allows you to pull schedules

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiSchedule1Request
*/
func (a *ScheduleAPIService) Schedule1(ctx context.Context) ApiSchedule1Request {
	return ApiSchedule1Request{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) Schedule1Execute(r ApiSchedule1Request) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.Schedule1")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/{scheduleType}"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.usingPrivateEndpoint == nil {
		return nil, reportError("usingPrivateEndpoint is required and must be specified")
	}

	if r.calendarTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "calendarTypes", r.calendarTypes, "", "")
	}
	if r.eventTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventTypes", r.eventTypes, "", "")
	}
	if r.scheduleEventTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "scheduleEventTypes", r.scheduleEventTypes, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.gamePk != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePk", r.gamePk, "", "")
	}
	if r.gamePks != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePks", r.gamePks, "", "")
	}
	if r.eventIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventIds", r.eventIds, "", "")
	}
	if r.venueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueIds", r.venueIds, "", "")
	}
	if r.performerIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "performerIds", r.performerIds, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.seasons != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seasons", r.seasons, "", "")
	}
	if r.date != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "date", r.date, "", "")
	}
	if r.startDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "startDate", r.startDate, "", "")
	}
	if r.endDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "endDate", r.endDate, "", "")
	}
	if r.timecode != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "timecode", r.timecode, "", "")
	}
	if r.useLatestGames != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useLatestGames", r.useLatestGames, "", "")
	}
	if r.opponentId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "opponentId", r.opponentId, "", "")
	}
	if r.publicFacing != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "publicFacing", r.publicFacing, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	parameterAddToHeaderOrQuery(localVarQueryParams, "usingPrivateEndpoint", r.usingPrivateEndpoint, "", "")
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiTieGamesRequest struct {
	ctx        context.Context
	ApiService *ScheduleAPIService
	season     *interface{}
	sportId    *interface{}
	gameTypes  *interface{}
	fields     *interface{}
}

// Season of play
func (r ApiTieGamesRequest) Season(season interface{}) ApiTieGamesRequest {
	r.season = &season
	return r
}

// Top level organization of a sport
func (r ApiTieGamesRequest) SportId(sportId interface{}) ApiTieGamesRequest {
	r.sportId = &sportId
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiTieGamesRequest) GameTypes(gameTypes interface{}) ApiTieGamesRequest {
	r.gameTypes = &gameTypes
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiTieGamesRequest) Fields(fields interface{}) ApiTieGamesRequest {
	r.fields = &fields
	return r
}

func (r ApiTieGamesRequest) Execute() (*http.Response, error) {
	return r.ApiService.TieGamesExecute(r)
}

/*
TieGames Get tied game schedules

This endpoint allows you to pull tie game schedules for the given season

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiTieGamesRequest
*/
func (a *ScheduleAPIService) TieGames(ctx context.Context) ApiTieGamesRequest {
	return ApiTieGamesRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) TieGamesExecute(r ApiTieGamesRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.TieGames")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/games/tied"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.season == nil {
		return nil, reportError("season is required and must be specified")
	}

	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiTrackingEventsScheduleRequest struct {
	ctx            context.Context
	ApiService     *ScheduleAPIService
	calendarTypes  *interface{}
	eventTypes     *interface{}
	teamId         *interface{}
	leagueId       *interface{}
	sportId        *interface{}
	gamePk         *interface{}
	gamePks        *interface{}
	eventIds       *interface{}
	venueIds       *interface{}
	performerIds   *interface{}
	gameTypes      *interface{}
	gameType       *interface{}
	season         *interface{}
	seasons        *interface{}
	date           *interface{}
	startDate      *interface{}
	endDate        *interface{}
	timecode       *interface{}
	useLatestGames *interface{}
	opponentId     *interface{}
	publicFacing   *interface{}
	fields         *interface{}
}

// Comma delimited list of type of calendar types
func (r ApiTrackingEventsScheduleRequest) CalendarTypes(calendarTypes interface{}) ApiTrackingEventsScheduleRequest {
	r.calendarTypes = &calendarTypes
	return r
}

// Comma delimited list of type of events. &lt;b&gt;Note: Don&#39;t Use. This will be deprecated in favor of calendarTypes&lt;/b&gt;
func (r ApiTrackingEventsScheduleRequest) EventTypes(eventTypes interface{}) ApiTrackingEventsScheduleRequest {
	r.eventTypes = &eventTypes
	return r
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiTrackingEventsScheduleRequest) TeamId(teamId interface{}) ApiTrackingEventsScheduleRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiTrackingEventsScheduleRequest) LeagueId(leagueId interface{}) ApiTrackingEventsScheduleRequest {
	r.leagueId = &leagueId
	return r
}

// Top level organization of a sport
func (r ApiTrackingEventsScheduleRequest) SportId(sportId interface{}) ApiTrackingEventsScheduleRequest {
	r.sportId = &sportId
	return r
}

// Unique Primary Key Representing a Game
func (r ApiTrackingEventsScheduleRequest) GamePk(gamePk interface{}) ApiTrackingEventsScheduleRequest {
	r.gamePk = &gamePk
	return r
}

// Comma delimited list of unique primary keys
func (r ApiTrackingEventsScheduleRequest) GamePks(gamePks interface{}) ApiTrackingEventsScheduleRequest {
	r.gamePks = &gamePks
	return r
}

// A unique identifier for non-game event
func (r ApiTrackingEventsScheduleRequest) EventIds(eventIds interface{}) ApiTrackingEventsScheduleRequest {
	r.eventIds = &eventIds
	return r
}

// Unique Venue Identifier
func (r ApiTrackingEventsScheduleRequest) VenueIds(venueIds interface{}) ApiTrackingEventsScheduleRequest {
	r.venueIds = &venueIds
	return r
}

// A unique identifier for non-team event performers
func (r ApiTrackingEventsScheduleRequest) PerformerIds(performerIds interface{}) ApiTrackingEventsScheduleRequest {
	r.performerIds = &performerIds
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiTrackingEventsScheduleRequest) GameTypes(gameTypes interface{}) ApiTrackingEventsScheduleRequest {
	r.gameTypes = &gameTypes
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiTrackingEventsScheduleRequest) GameType(gameType interface{}) ApiTrackingEventsScheduleRequest {
	r.gameType = &gameType
	return r
}

// Season of play
func (r ApiTrackingEventsScheduleRequest) Season(season interface{}) ApiTrackingEventsScheduleRequest {
	r.season = &season
	return r
}

// Comma delimited list of Seasons of play
func (r ApiTrackingEventsScheduleRequest) Seasons(seasons interface{}) ApiTrackingEventsScheduleRequest {
	r.seasons = &seasons
	return r
}

// Date of Game. Format: YYYY-MM-DD
func (r ApiTrackingEventsScheduleRequest) Date(date interface{}) ApiTrackingEventsScheduleRequest {
	r.date = &date
	return r
}

// Start date for range of data (must be used with end date). Format: MM/DD/YYYY
func (r ApiTrackingEventsScheduleRequest) StartDate(startDate interface{}) ApiTrackingEventsScheduleRequest {
	r.startDate = &startDate
	return r
}

// End date for range of data (must be used with start date). Format: MM/DD/YYYY
func (r ApiTrackingEventsScheduleRequest) EndDate(endDate interface{}) ApiTrackingEventsScheduleRequest {
	r.endDate = &endDate
	return r
}

// Use this parameter to return a snapshot of the data at the specified time. Format: YYYYMMDD_HHMMSS
func (r ApiTrackingEventsScheduleRequest) Timecode(timecode interface{}) ApiTrackingEventsScheduleRequest {
	r.timecode = &timecode
	return r
}

func (r ApiTrackingEventsScheduleRequest) UseLatestGames(useLatestGames interface{}) ApiTrackingEventsScheduleRequest {
	r.useLatestGames = &useLatestGames
	return r
}

// A unique identifier for the opposing team. Must be used with Team ID
func (r ApiTrackingEventsScheduleRequest) OpponentId(opponentId interface{}) ApiTrackingEventsScheduleRequest {
	r.opponentId = &opponentId
	return r
}

// Return public, non-public or all games. Format: Public Facing &#x3D; &#39;Y&#39;, Non-Public Facing &#x3D; &#39;N&#39;, All &#x3D; &#39;A&#39;
func (r ApiTrackingEventsScheduleRequest) PublicFacing(publicFacing interface{}) ApiTrackingEventsScheduleRequest {
	r.publicFacing = &publicFacing
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiTrackingEventsScheduleRequest) Fields(fields interface{}) ApiTrackingEventsScheduleRequest {
	r.fields = &fields
	return r
}

func (r ApiTrackingEventsScheduleRequest) Execute() (*http.Response, error) {
	return r.ApiService.TrackingEventsScheduleExecute(r)
}

/*
TrackingEventsSchedule Get tracking event schedules

This endpoint allows you to pull schedules for tracking events

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiTrackingEventsScheduleRequest
*/
func (a *ScheduleAPIService) TrackingEventsSchedule(ctx context.Context) ApiTrackingEventsScheduleRequest {
	return ApiTrackingEventsScheduleRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) TrackingEventsScheduleExecute(r ApiTrackingEventsScheduleRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.TrackingEventsSchedule")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/trackingEvents"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.calendarTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "calendarTypes", r.calendarTypes, "", "")
	}
	if r.eventTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventTypes", r.eventTypes, "", "")
	}
	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.gamePk != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePk", r.gamePk, "", "")
	}
	if r.gamePks != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gamePks", r.gamePks, "", "")
	}
	if r.eventIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "eventIds", r.eventIds, "", "")
	}
	if r.venueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueIds", r.venueIds, "", "")
	}
	if r.performerIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "performerIds", r.performerIds, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.seasons != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seasons", r.seasons, "", "")
	}
	if r.date != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "date", r.date, "", "")
	}
	if r.startDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "startDate", r.startDate, "", "")
	}
	if r.endDate != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "endDate", r.endDate, "", "")
	}
	if r.timecode != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "timecode", r.timecode, "", "")
	}
	if r.useLatestGames != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "useLatestGames", r.useLatestGames, "", "")
	}
	if r.opponentId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "opponentId", r.opponentId, "", "")
	}
	if r.publicFacing != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "publicFacing", r.publicFacing, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiTuneInRequest struct {
	ctx        context.Context
	ApiService *ScheduleAPIService
	teamId     *interface{}
	sportId    *interface{}
	season     *interface{}
	fields     *interface{}
}

// Unique Team Identifier. Format: 141, 147, etc
func (r ApiTuneInRequest) TeamId(teamId interface{}) ApiTuneInRequest {
	r.teamId = &teamId
	return r
}

// Unique League Identifier
func (r ApiTuneInRequest) SportId(sportId interface{}) ApiTuneInRequest {
	r.sportId = &sportId
	return r
}

// Unique Primary Key Representing a Game
func (r ApiTuneInRequest) Season(season interface{}) ApiTuneInRequest {
	r.season = &season
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiTuneInRequest) Fields(fields interface{}) ApiTuneInRequest {
	r.fields = &fields
	return r
}

func (r ApiTuneInRequest) Execute() (*http.Response, error) {
	return r.ApiService.TuneInExecute(r)
}

/*
TuneIn Get postseason TuneIn schedules

This endpoint allows you to pull postseason schedules

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiTuneInRequest
*/
func (a *ScheduleAPIService) TuneIn(ctx context.Context) ApiTuneInRequest {
	return ApiTuneInRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *ScheduleAPIService) TuneInExecute(r ApiTuneInRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "ScheduleAPIService.TuneIn")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/schedule/postseason/tuneIn"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.teamId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "teamId", r.teamId, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
