/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
)

// UniformsAPIService UniformsAPI service
type UniformsAPIService service

type ApiUniformsByGameRequest struct {
	ctx        context.Context
	ApiService *UniformsAPIService
	gamePks    *interface{}
	fields     *interface{}
}

// Comma delimited list of unique primary keys
func (r ApiUniformsByGameRequest) GamePks(gamePks interface{}) ApiUniformsByGameRequest {
	r.gamePks = &gamePks
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiUniformsByGameRequest) Fields(fields interface{}) ApiUniformsByGameRequest {
	r.fields = &fields
	return r
}

func (r ApiUniformsByGameRequest) Execute() (*http.Response, error) {
	return r.ApiService.UniformsByGameExecute(r)
}

/*
UniformsByGame View Game Uniform info

This endpoint allows you to pull team uniform data for a game

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiUniformsByGameRequest
*/
func (a *UniformsAPIService) UniformsByGame(ctx context.Context) ApiUniformsByGameRequest {
	return ApiUniformsByGameRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *UniformsAPIService) UniformsByGameExecute(r ApiUniformsByGameRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "UniformsAPIService.UniformsByGame")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/uniforms/game"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.gamePks == nil {
		return nil, reportError("gamePks is required and must be specified")
	}

	parameterAddToHeaderOrQuery(localVarQueryParams, "gamePks", r.gamePks, "", "")
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiUniformsByTeamRequest struct {
	ctx        context.Context
	ApiService *UniformsAPIService
	teamIds    *interface{}
	season     *interface{}
	fields     *interface{}
}

func (r ApiUniformsByTeamRequest) TeamIds(teamIds interface{}) ApiUniformsByTeamRequest {
	r.teamIds = &teamIds
	return r
}

// Season of play
func (r ApiUniformsByTeamRequest) Season(season interface{}) ApiUniformsByTeamRequest {
	r.season = &season
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiUniformsByTeamRequest) Fields(fields interface{}) ApiUniformsByTeamRequest {
	r.fields = &fields
	return r
}

func (r ApiUniformsByTeamRequest) Execute() (*http.Response, error) {
	return r.ApiService.UniformsByTeamExecute(r)
}

/*
UniformsByTeam View Team Uniform info

This endpoint allows you to pull team uniform data for a season

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@return ApiUniformsByTeamRequest
*/
func (a *UniformsAPIService) UniformsByTeam(ctx context.Context) ApiUniformsByTeamRequest {
	return ApiUniformsByTeamRequest{
		ApiService: a,
		ctx:        ctx,
	}
}

// Execute executes the request
func (a *UniformsAPIService) UniformsByTeamExecute(r ApiUniformsByTeamRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "UniformsAPIService.UniformsByTeam")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/uniforms/team"

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}
	if r.teamIds == nil {
		return nil, reportError("teamIds is required and must be specified")
	}

	parameterAddToHeaderOrQuery(localVarQueryParams, "teamIds", r.teamIds, "", "")
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
