/*
Copyright © 2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
/*
Stats API Documentation

Official API for Major League Baseball.

API version: 2.0.0
*/

// Code generated by OpenAPI Generator (https://openapi-generator.tech); DO NOT EDIT.

package api

import (
	"bytes"
	"context"
	"io"
	"net/http"
	"net/url"
	"strings"
)

// VenuesAPIService VenuesAPI service
type VenuesAPIService service

type ApiVenuesRequest struct {
	ctx           context.Context
	ApiService    *VenuesAPIService
	venueId       interface{}
	venueIds      *interface{}
	leagueId      *interface{}
	leagueIds     *interface{}
	gameType      *interface{}
	gameTypes     *interface{}
	season        *interface{}
	seasons       *interface{}
	fields        *interface{}
	active        *interface{}
	includeEvents *interface{}
	sportId       *interface{}
	sportIds      *interface{}
}

// Comma delimited list of Unique venue identifiers
func (r ApiVenuesRequest) VenueIds(venueIds interface{}) ApiVenuesRequest {
	r.venueIds = &venueIds
	return r
}

// Unique League Identifier
func (r ApiVenuesRequest) LeagueId(leagueId interface{}) ApiVenuesRequest {
	r.leagueId = &leagueId
	return r
}

// Comma delimited list of Unique league identifiers
func (r ApiVenuesRequest) LeagueIds(leagueIds interface{}) ApiVenuesRequest {
	r.leagueIds = &leagueIds
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiVenuesRequest) GameType(gameType interface{}) ApiVenuesRequest {
	r.gameType = &gameType
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiVenuesRequest) GameTypes(gameTypes interface{}) ApiVenuesRequest {
	r.gameTypes = &gameTypes
	return r
}

// Season of play
func (r ApiVenuesRequest) Season(season interface{}) ApiVenuesRequest {
	r.season = &season
	return r
}

// Comma delimited list of Seasons of play
func (r ApiVenuesRequest) Seasons(seasons interface{}) ApiVenuesRequest {
	r.seasons = &seasons
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiVenuesRequest) Fields(fields interface{}) ApiVenuesRequest {
	r.fields = &fields
	return r
}

// Whether or not a player is active
func (r ApiVenuesRequest) Active(active interface{}) ApiVenuesRequest {
	r.active = &active
	return r
}

func (r ApiVenuesRequest) IncludeEvents(includeEvents interface{}) ApiVenuesRequest {
	r.includeEvents = &includeEvents
	return r
}

// Top level organization of a sport
func (r ApiVenuesRequest) SportId(sportId interface{}) ApiVenuesRequest {
	r.sportId = &sportId
	return r
}

// Comma delimited list of top level organizations of a sport
func (r ApiVenuesRequest) SportIds(sportIds interface{}) ApiVenuesRequest {
	r.sportIds = &sportIds
	return r
}

func (r ApiVenuesRequest) Execute() (*http.Response, error) {
	return r.ApiService.VenuesExecute(r)
}

/*
Venues View venue info

This endpoint allows you to pull venues

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param venueId Unique Venue Identifier
	@return ApiVenuesRequest
*/
func (a *VenuesAPIService) Venues(ctx context.Context, venueId interface{}) ApiVenuesRequest {
	return ApiVenuesRequest{
		ApiService: a,
		ctx:        ctx,
		venueId:    venueId,
	}
}

// Execute executes the request
func (a *VenuesAPIService) VenuesExecute(r ApiVenuesRequest) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "VenuesAPIService.Venues")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/venues"
	localVarPath = strings.Replace(localVarPath, "{"+"venueId"+"}", url.PathEscape(parameterValueToString(r.venueId, "venueId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.venueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueIds", r.venueIds, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.leagueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueIds", r.leagueIds, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.seasons != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seasons", r.seasons, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	if r.active != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "active", r.active, "", "")
	}
	if r.includeEvents != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeEvents", r.includeEvents, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.sportIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportIds", r.sportIds, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}

type ApiVenues1Request struct {
	ctx           context.Context
	ApiService    *VenuesAPIService
	venueId       interface{}
	venueIds      *interface{}
	leagueId      *interface{}
	leagueIds     *interface{}
	gameType      *interface{}
	gameTypes     *interface{}
	season        *interface{}
	seasons       *interface{}
	fields        *interface{}
	active        *interface{}
	includeEvents *interface{}
	sportId       *interface{}
	sportIds      *interface{}
}

// Comma delimited list of Unique venue identifiers
func (r ApiVenues1Request) VenueIds(venueIds interface{}) ApiVenues1Request {
	r.venueIds = &venueIds
	return r
}

// Unique League Identifier
func (r ApiVenues1Request) LeagueId(leagueId interface{}) ApiVenues1Request {
	r.leagueId = &leagueId
	return r
}

// Comma delimited list of Unique league identifiers
func (r ApiVenues1Request) LeagueIds(leagueIds interface{}) ApiVenues1Request {
	r.leagueIds = &leagueIds
	return r
}

// Type of Game. Available types in /api/v1/gameTypes
func (r ApiVenues1Request) GameType(gameType interface{}) ApiVenues1Request {
	r.gameType = &gameType
	return r
}

// Comma delimited list of type of Game. Available types in /api/v1/gameTypes
func (r ApiVenues1Request) GameTypes(gameTypes interface{}) ApiVenues1Request {
	r.gameTypes = &gameTypes
	return r
}

// Season of play
func (r ApiVenues1Request) Season(season interface{}) ApiVenues1Request {
	r.season = &season
	return r
}

// Comma delimited list of Seasons of play
func (r ApiVenues1Request) Seasons(seasons interface{}) ApiVenues1Request {
	r.seasons = &seasons
	return r
}

// Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute
func (r ApiVenues1Request) Fields(fields interface{}) ApiVenues1Request {
	r.fields = &fields
	return r
}

// Whether or not a player is active
func (r ApiVenues1Request) Active(active interface{}) ApiVenues1Request {
	r.active = &active
	return r
}

func (r ApiVenues1Request) IncludeEvents(includeEvents interface{}) ApiVenues1Request {
	r.includeEvents = &includeEvents
	return r
}

// Top level organization of a sport
func (r ApiVenues1Request) SportId(sportId interface{}) ApiVenues1Request {
	r.sportId = &sportId
	return r
}

// Comma delimited list of top level organizations of a sport
func (r ApiVenues1Request) SportIds(sportIds interface{}) ApiVenues1Request {
	r.sportIds = &sportIds
	return r
}

func (r ApiVenues1Request) Execute() (*http.Response, error) {
	return r.ApiService.Venues1Execute(r)
}

/*
Venues1 View venue info

This endpoint allows you to pull venues

	@param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
	@param venueId Unique Venue Identifier
	@return ApiVenues1Request
*/
func (a *VenuesAPIService) Venues1(ctx context.Context, venueId interface{}) ApiVenues1Request {
	return ApiVenues1Request{
		ApiService: a,
		ctx:        ctx,
		venueId:    venueId,
	}
}

// Execute executes the request
func (a *VenuesAPIService) Venues1Execute(r ApiVenues1Request) (*http.Response, error) {
	var (
		localVarHTTPMethod = http.MethodGet
		localVarPostBody   interface{}
		formFiles          []formFile
	)

	localBasePath, err := a.client.cfg.ServerURLWithContext(r.ctx, "VenuesAPIService.Venues1")
	if err != nil {
		return nil, &GenericOpenAPIError{error: err.Error()}
	}

	localVarPath := localBasePath + "/api/v1/venues/{venueId}"
	localVarPath = strings.Replace(localVarPath, "{"+"venueId"+"}", url.PathEscape(parameterValueToString(r.venueId, "venueId")), -1)

	localVarHeaderParams := make(map[string]string)
	localVarQueryParams := url.Values{}
	localVarFormParams := url.Values{}

	if r.venueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "venueIds", r.venueIds, "", "")
	}
	if r.leagueId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueId", r.leagueId, "", "")
	}
	if r.leagueIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "leagueIds", r.leagueIds, "", "")
	}
	if r.gameType != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameType", r.gameType, "", "")
	}
	if r.gameTypes != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "gameTypes", r.gameTypes, "", "")
	}
	if r.season != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "season", r.season, "", "")
	}
	if r.seasons != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "seasons", r.seasons, "", "")
	}
	if r.fields != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "fields", r.fields, "", "")
	}
	if r.active != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "active", r.active, "", "")
	}
	if r.includeEvents != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "includeEvents", r.includeEvents, "", "")
	}
	if r.sportId != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportId", r.sportId, "", "")
	}
	if r.sportIds != nil {
		parameterAddToHeaderOrQuery(localVarQueryParams, "sportIds", r.sportIds, "", "")
	}
	// to determine the Content-Type header
	localVarHTTPContentTypes := []string{}

	// set Content-Type header
	localVarHTTPContentType := selectHeaderContentType(localVarHTTPContentTypes)
	if localVarHTTPContentType != "" {
		localVarHeaderParams["Content-Type"] = localVarHTTPContentType
	}

	// to determine the Accept header
	localVarHTTPHeaderAccepts := []string{}

	// set Accept header
	localVarHTTPHeaderAccept := selectHeaderAccept(localVarHTTPHeaderAccepts)
	if localVarHTTPHeaderAccept != "" {
		localVarHeaderParams["Accept"] = localVarHTTPHeaderAccept
	}
	req, err := a.client.prepareRequest(r.ctx, localVarPath, localVarHTTPMethod, localVarPostBody, localVarHeaderParams, localVarQueryParams, localVarFormParams, formFiles)
	if err != nil {
		return nil, err
	}

	localVarHTTPResponse, err := a.client.callAPI(req)
	if err != nil || localVarHTTPResponse == nil {
		return localVarHTTPResponse, err
	}

	localVarBody, err := io.ReadAll(localVarHTTPResponse.Body)
	localVarHTTPResponse.Body.Close()
	localVarHTTPResponse.Body = io.NopCloser(bytes.NewBuffer(localVarBody))
	if err != nil {
		return localVarHTTPResponse, err
	}

	if localVarHTTPResponse.StatusCode >= 300 {
		newErr := &GenericOpenAPIError{
			body:  localVarBody,
			error: localVarHTTPResponse.Status,
		}
		return localVarHTTPResponse, newErr
	}

	return localVarHTTPResponse, nil
}
