# \AnalyticsAPI

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**ContextMetrics**](AnalyticsAPI.md#ContextMetrics) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetrics | Get context metrics for a specific gamePk.
[**ContextMetricsWithAverages**](AnalyticsAPI.md#ContextMetricsWithAverages) | **Get** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
[**ContextMetricsWithAveragesPost**](AnalyticsAPI.md#ContextMetricsWithAveragesPost) | **Post** /api/v1/game/{gamePk}/{guid}/contextMetricsAverages | Get a json file containing raw coordinate data and refined calculated metrics.
[**GameGuids**](AnalyticsAPI.md#GameGuids) | **Get** /api/v1/game/{gamePk}/guids | Get the GUIDs (plays) for a specific game. 
[**GameGuidsFromPostgresRange**](AnalyticsAPI.md#GameGuidsFromPostgresRange) | **Get** /api/v1/analytics/guids | Get the GUIDs (plays) for a specific game. 
[**GameGuidsFromPostgresRangeByGame**](AnalyticsAPI.md#GameGuidsFromPostgresRangeByGame) | **Get** /api/v1/analytics/game | Get all games by updated date.
[**GameLastPitch**](AnalyticsAPI.md#GameLastPitch) | **Get** /api/v1/game/lastPitch | Get the last pitch for a list of games
[**HomeRunBallparks**](AnalyticsAPI.md#HomeRunBallparks) | **Get** /api/v1/game/{gamePk}/{guid}/homeRunBallparks | Get if the play is a home run is each park for a specific play.
[**ParsedJsonFormattedAnalytics**](AnalyticsAPI.md#ParsedJsonFormattedAnalytics) | **Get** /api/v1/game/{gamePk}/{guid}/analytics | Get Statcast data for a specific play.



## ContextMetrics

> ContextMetrics(ctx, gamePk, guid).Fields(fields).Execute()

Get context metrics for a specific gamePk.



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	guid := TODO // interface{} | Unique identifier for a play within a game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.ContextMetrics(context.Background(), gamePk, guid).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.ContextMetrics``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 
**guid** | [**interface{}**](.md) | Unique identifier for a play within a game | 

### Other Parameters

Other parameters are passed through a pointer to a apiContextMetricsRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------


 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ContextMetricsWithAverages

> ContextMetricsWithAverages(ctx, gamePk, guid).Fields(fields).Execute()

Get a json file containing raw coordinate data and refined calculated metrics.



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	guid := TODO // interface{} | Unique identifier for a play within a game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.ContextMetricsWithAverages(context.Background(), gamePk, guid).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.ContextMetricsWithAverages``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 
**guid** | [**interface{}**](.md) | Unique identifier for a play within a game | 

### Other Parameters

Other parameters are passed through a pointer to a apiContextMetricsWithAveragesRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------


 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ContextMetricsWithAveragesPost

> ContextMetricsWithAveragesPost(ctx, gamePk, guid).Fields(fields).Execute()

Get a json file containing raw coordinate data and refined calculated metrics.



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	guid := TODO // interface{} | Unique identifier for a play within a game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.ContextMetricsWithAveragesPost(context.Background(), gamePk, guid).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.ContextMetricsWithAveragesPost``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 
**guid** | [**interface{}**](.md) | Unique identifier for a play within a game | 

### Other Parameters

Other parameters are passed through a pointer to a apiContextMetricsWithAveragesPostRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------


 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## GameGuids

> GameGuids(ctx, gamePk).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).HasUpdates(hasUpdates).Since(since).UpdatedSince(updatedSince).LastPlayTime(lastPlayTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).LastVideoUpdatedTime(lastVideoUpdatedTime).Execute()

Get the GUIDs (plays) for a specific game. 

### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)
	gameModeId := TODO // interface{} | Statcast game mode. Format: 0 = Batting Practive, 1 = Warmup 2 = Live (optional)
	isPitch := TODO // interface{} | If there was a pitch (optional)
	isHit := TODO // interface{} | If there was a hit ball tracked (optional)
	isPickoff := TODO // interface{} | If there was a pickoff (optional)
	hasUpdates := TODO // interface{} | True if updated by an auditor (optional)
	since := TODO // interface{} | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	updatedSince := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastPlayTime := TODO // interface{} | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastMetricsUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastAuditUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastVideoUpdatedTime := TODO // interface{} | The last time SportyBot video was updated (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.GameGuids(context.Background(), gamePk).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).HasUpdates(hasUpdates).Since(since).UpdatedSince(updatedSince).LastPlayTime(lastPlayTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).LastVideoUpdatedTime(lastVideoUpdatedTime).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.GameGuids``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 

### Other Parameters

Other parameters are passed through a pointer to a apiGameGuidsRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 
 **gameModeId** | [**interface{}**](interface{}.md) | Statcast game mode. Format: 0 &#x3D; Batting Practive, 1 &#x3D; Warmup 2 &#x3D; Live | 
 **isPitch** | [**interface{}**](interface{}.md) | If there was a pitch | 
 **isHit** | [**interface{}**](interface{}.md) | If there was a hit ball tracked | 
 **isPickoff** | [**interface{}**](interface{}.md) | If there was a pickoff | 
 **hasUpdates** | [**interface{}**](interface{}.md) | True if updated by an auditor | 
 **since** | [**interface{}**](interface{}.md) | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **updatedSince** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastPlayTime** | [**interface{}**](interface{}.md) | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastMetricsUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastAuditUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastVideoUpdatedTime** | [**interface{}**](interface{}.md) | The last time SportyBot video was updated | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## GameGuidsFromPostgresRange

> GameGuidsFromPostgresRange(ctx).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).IsNonStatcast(isNonStatcast).GamedayType(gamedayType).HasUpdates(hasUpdates).LastPlayTime(lastPlayTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).LastVideoUpdatedTime(lastVideoUpdatedTime).GameDate(gameDate).SportId(sportId).GameType(gameType).TrackingSystemOwner(trackingSystemOwner).Season(season).SortBy(sortBy).Limit(limit).Offset(offset).Execute()

Get the GUIDs (plays) for a specific game. 

### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)
	gameModeId := TODO // interface{} | Statcast game mode. Format: 0 = Batting Practive, 1 = Warmup 2 = Live (optional)
	isPitch := TODO // interface{} | If there was a pitch (optional)
	isHit := TODO // interface{} | If there was a hit ball tracked (optional)
	isPickoff := TODO // interface{} | If there was a pickoff (optional)
	isNonStatcast := TODO // interface{} | If non statcast games need to be included (optional)
	gamedayType := TODO // interface{} | Indicates the level of Gameday (tracking, play-by-play, linescore, etc...) (optional)
	hasUpdates := TODO // interface{} | True if updated by an auditor (optional)
	lastPlayTime := TODO // interface{} | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastMetricsUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastAuditUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastVideoUpdatedTime := TODO // interface{} | The last time SportyBot video was updated (optional)
	gameDate := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	gameType := TODO // interface{} | Type of Game. Available types in /api/v1/gameTypes (optional)
	trackingSystemOwner := TODO // interface{} | Owner of the tracking system (optional)
	season := TODO // interface{} | Season of play (optional)
	sortBy := TODO // interface{} | Sort the set of data by the specified field (optional)
	limit := TODO // interface{} | Number of results to return (optional)
	offset := TODO // interface{} | The pointer to start for a return set; used for pagination (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.GameGuidsFromPostgresRange(context.Background()).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).IsNonStatcast(isNonStatcast).GamedayType(gamedayType).HasUpdates(hasUpdates).LastPlayTime(lastPlayTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).LastVideoUpdatedTime(lastVideoUpdatedTime).GameDate(gameDate).SportId(sportId).GameType(gameType).TrackingSystemOwner(trackingSystemOwner).Season(season).SortBy(sortBy).Limit(limit).Offset(offset).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.GameGuidsFromPostgresRange``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiGameGuidsFromPostgresRangeRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 
 **gameModeId** | [**interface{}**](interface{}.md) | Statcast game mode. Format: 0 &#x3D; Batting Practive, 1 &#x3D; Warmup 2 &#x3D; Live | 
 **isPitch** | [**interface{}**](interface{}.md) | If there was a pitch | 
 **isHit** | [**interface{}**](interface{}.md) | If there was a hit ball tracked | 
 **isPickoff** | [**interface{}**](interface{}.md) | If there was a pickoff | 
 **isNonStatcast** | [**interface{}**](interface{}.md) | If non statcast games need to be included | 
 **gamedayType** | [**interface{}**](interface{}.md) | Indicates the level of Gameday (tracking, play-by-play, linescore, etc...) | 
 **hasUpdates** | [**interface{}**](interface{}.md) | True if updated by an auditor | 
 **lastPlayTime** | [**interface{}**](interface{}.md) | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastMetricsUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastAuditUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastVideoUpdatedTime** | [**interface{}**](interface{}.md) | The last time SportyBot video was updated | 
 **gameDate** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **gameType** | [**interface{}**](interface{}.md) | Type of Game. Available types in /api/v1/gameTypes | 
 **trackingSystemOwner** | [**interface{}**](interface{}.md) | Owner of the tracking system | 
 **season** | [**interface{}**](interface{}.md) | Season of play | 
 **sortBy** | [**interface{}**](interface{}.md) | Sort the set of data by the specified field | 
 **limit** | [**interface{}**](interface{}.md) | Number of results to return | 
 **offset** | [**interface{}**](interface{}.md) | The pointer to start for a return set; used for pagination | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## GameGuidsFromPostgresRangeByGame

> GameGuidsFromPostgresRangeByGame(ctx).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).IsNonStatcast(isNonStatcast).GamedayType(gamedayType).HasUpdates(hasUpdates).LastPlayTime(lastPlayTime).LastVideoUpdatedTime(lastVideoUpdatedTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).GameDate(gameDate).SportId(sportId).GameType(gameType).Season(season).TrackingSystemOwner(trackingSystemOwner).SortBy(sortBy).Limit(limit).Offset(offset).ScheduleEventTypes(scheduleEventTypes).Execute()

Get all games by updated date.

### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)
	gameModeId := TODO // interface{} | Statcast game mode. Format: 0 = Batting Practive, 1 = Warmup 2 = Live (optional)
	isPitch := TODO // interface{} | If there was a pitch (optional)
	isHit := TODO // interface{} | If there was a hit ball tracked (optional)
	isPickoff := TODO // interface{} | If there was a pickoff (optional)
	isNonStatcast := TODO // interface{} | If non statcast games need to be included (optional)
	gamedayType := TODO // interface{} | Indicates the level of Gameday (tracking, play-by-play, linescore, etc...) (optional)
	hasUpdates := TODO // interface{} | True if updated by an auditor (optional)
	lastPlayTime := TODO // interface{} | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastVideoUpdatedTime := TODO // interface{} | The last time SportyBot video was updated (optional)
	lastUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastMetricsUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	lastAuditUpdatedTime := TODO // interface{} | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ (optional)
	gameDate := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	gameType := TODO // interface{} | Type of Game. Available types in /api/v1/gameTypes (optional)
	season := TODO // interface{} | Season of play (optional)
	trackingSystemOwner := TODO // interface{} | Owner of the tracking system (optional)
	sortBy := TODO // interface{} | Sort the set of data by the specified field (optional)
	limit := TODO // interface{} | Number of results to return (optional)
	offset := TODO // interface{} | The pointer to start for a return set; used for pagination (optional)
	scheduleEventTypes := TODO // interface{} | Comma delimited list of type of event types (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.GameGuidsFromPostgresRangeByGame(context.Background()).Fields(fields).GameModeId(gameModeId).IsPitch(isPitch).IsHit(isHit).IsPickoff(isPickoff).IsNonStatcast(isNonStatcast).GamedayType(gamedayType).HasUpdates(hasUpdates).LastPlayTime(lastPlayTime).LastVideoUpdatedTime(lastVideoUpdatedTime).LastUpdatedTime(lastUpdatedTime).LastMetricsUpdatedTime(lastMetricsUpdatedTime).LastAuditUpdatedTime(lastAuditUpdatedTime).GameDate(gameDate).SportId(sportId).GameType(gameType).Season(season).TrackingSystemOwner(trackingSystemOwner).SortBy(sortBy).Limit(limit).Offset(offset).ScheduleEventTypes(scheduleEventTypes).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.GameGuidsFromPostgresRangeByGame``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiGameGuidsFromPostgresRangeByGameRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 
 **gameModeId** | [**interface{}**](interface{}.md) | Statcast game mode. Format: 0 &#x3D; Batting Practive, 1 &#x3D; Warmup 2 &#x3D; Live | 
 **isPitch** | [**interface{}**](interface{}.md) | If there was a pitch | 
 **isHit** | [**interface{}**](interface{}.md) | If there was a hit ball tracked | 
 **isPickoff** | [**interface{}**](interface{}.md) | If there was a pickoff | 
 **isNonStatcast** | [**interface{}**](interface{}.md) | If non statcast games need to be included | 
 **gamedayType** | [**interface{}**](interface{}.md) | Indicates the level of Gameday (tracking, play-by-play, linescore, etc...) | 
 **hasUpdates** | [**interface{}**](interface{}.md) | True if updated by an auditor | 
 **lastPlayTime** | [**interface{}**](interface{}.md) | Returns all data that was created after the specified timestamp. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastVideoUpdatedTime** | [**interface{}**](interface{}.md) | The last time SportyBot video was updated | 
 **lastUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastMetricsUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **lastAuditUpdatedTime** | [**interface{}**](interface{}.md) | Return data updated since a specified date. Format: YYYY-MM-DDTHH:MM:SSZ | 
 **gameDate** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **gameType** | [**interface{}**](interface{}.md) | Type of Game. Available types in /api/v1/gameTypes | 
 **season** | [**interface{}**](interface{}.md) | Season of play | 
 **trackingSystemOwner** | [**interface{}**](interface{}.md) | Owner of the tracking system | 
 **sortBy** | [**interface{}**](interface{}.md) | Sort the set of data by the specified field | 
 **limit** | [**interface{}**](interface{}.md) | Number of results to return | 
 **offset** | [**interface{}**](interface{}.md) | The pointer to start for a return set; used for pagination | 
 **scheduleEventTypes** | [**interface{}**](interface{}.md) | Comma delimited list of type of event types | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## GameLastPitch

> GameLastPitch(ctx).GamePks(gamePks).Fields(fields).Execute()

Get the last pitch for a list of games

### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePks := TODO // interface{} | Unique Primary Key Representing a Game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.GameLastPitch(context.Background()).GamePks(gamePks).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.GameLastPitch``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiGameLastPitchRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **gamePks** | [**interface{}**](interface{}.md) | Unique Primary Key Representing a Game | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## HomeRunBallparks

> HomeRunBallparks(ctx, gamePk, guid).IsHomeRunParks(isHomeRunParks).Fields(fields).Execute()

Get if the play is a home run is each park for a specific play.



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	guid := TODO // interface{} | Unique identifier for a play within a game
	isHomeRunParks := TODO // interface{} | 
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.HomeRunBallparks(context.Background(), gamePk, guid).IsHomeRunParks(isHomeRunParks).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.HomeRunBallparks``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 
**guid** | [**interface{}**](.md) | Unique identifier for a play within a game | 

### Other Parameters

Other parameters are passed through a pointer to a apiHomeRunBallparksRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------


 **isHomeRunParks** | [**interface{}**](interface{}.md) |  | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## ParsedJsonFormattedAnalytics

> ParsedJsonFormattedAnalytics(ctx, gamePk, guid).Fields(fields).Execute()

Get Statcast data for a specific play.



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	gamePk := TODO // interface{} | Unique Primary Key Representing a Game
	guid := TODO // interface{} | Unique identifier for a play within a game
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.AnalyticsAPI.ParsedJsonFormattedAnalytics(context.Background(), gamePk, guid).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `AnalyticsAPI.ParsedJsonFormattedAnalytics``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**gamePk** | [**interface{}**](.md) | Unique Primary Key Representing a Game | 
**guid** | [**interface{}**](.md) | Unique identifier for a play within a game | 

### Other Parameters

Other parameters are passed through a pointer to a apiParsedJsonFormattedAnalyticsRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------


 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)

