# \JobAPI

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**Datacasters**](JobAPI.md#Datacasters) | **Get** /api/v1/jobs/datacasters | Get datacaster jobs
[**GetJobsByType**](JobAPI.md#GetJobsByType) | **Get** /api/v1/jobs | Get jobs by type
[**OfficialScorers**](JobAPI.md#OfficialScorers) | **Get** /api/v1/jobs/officialScorers | Get official scorers
[**UmpireSchedule**](JobAPI.md#UmpireSchedule) | **Get** /api/v1/jobs/umpires/games/{umpireId} | Get umpires and associated game for umpireId
[**Umpires**](JobAPI.md#Umpires) | **Get** /api/v1/jobs/umpires | Get umpires



## Datacasters

> Datacasters(ctx).SportId(sportId).Date(date).Fields(fields).Execute()

Get datacaster jobs



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	date := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.JobAPI.Datacasters(context.Background()).SportId(sportId).Date(date).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `JobAPI.Datacasters``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiDatacastersRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **date** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## GetJobsByType

> GetJobsByType(ctx).JobType(jobType).SportId(sportId).Date(date).Fields(fields).Execute()

Get jobs by type



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	jobType := TODO // interface{} | Job Type Identifier (ie. UMPR, etc..)
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	date := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.JobAPI.GetJobsByType(context.Background()).JobType(jobType).SportId(sportId).Date(date).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `JobAPI.GetJobsByType``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiGetJobsByTypeRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **jobType** | [**interface{}**](interface{}.md) | Job Type Identifier (ie. UMPR, etc..) | 
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **date** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## OfficialScorers

> OfficialScorers(ctx).SportId(sportId).Date(date).Fields(fields).Execute()

Get official scorers



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	date := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.JobAPI.OfficialScorers(context.Background()).SportId(sportId).Date(date).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `JobAPI.OfficialScorers``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiOfficialScorersRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **date** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## UmpireSchedule

> UmpireSchedule(ctx, umpireId).Season(season).Fields(fields).Execute()

Get umpires and associated game for umpireId



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	umpireId := TODO // interface{} | A unique identifier for an umpire
	season := TODO // interface{} | Season of play
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.JobAPI.UmpireSchedule(context.Background(), umpireId).Season(season).Fields(fields).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `JobAPI.UmpireSchedule``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
**ctx** | **context.Context** | context for authentication, logging, cancellation, deadlines, tracing, etc.
**umpireId** | [**interface{}**](.md) | A unique identifier for an umpire | 

### Other Parameters

Other parameters are passed through a pointer to a apiUmpireScheduleRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------

 **season** | [**interface{}**](interface{}.md) | Season of play | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)


## Umpires

> Umpires(ctx).SportId(sportId).Date(date).Fields(fields).Season(season).Execute()

Get umpires



### Example

```go
package main

import (
	"context"
	"fmt"
	"os"
	openapiclient "//"
)

func main() {
	sportId := TODO // interface{} | Top level organization of a sport (optional)
	date := TODO // interface{} | Date of Game. Format: YYYY-MM-DD (optional)
	fields := TODO // interface{} | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute (optional)
	season := TODO // interface{} | Season of play (optional)

	configuration := openapiclient.NewConfiguration()
	apiClient := openapiclient.NewAPIClient(configuration)
	r, err := apiClient.JobAPI.Umpires(context.Background()).SportId(sportId).Date(date).Fields(fields).Season(season).Execute()
	if err != nil {
		fmt.Fprintf(os.Stderr, "Error when calling `JobAPI.Umpires``: %v\n", err)
		fmt.Fprintf(os.Stderr, "Full HTTP response: %v\n", r)
	}
}
```

### Path Parameters



### Other Parameters

Other parameters are passed through a pointer to a apiUmpiresRequest struct via the builder pattern


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **sportId** | [**interface{}**](interface{}.md) | Top level organization of a sport | 
 **date** | [**interface{}**](interface{}.md) | Date of Game. Format: YYYY-MM-DD | 
 **fields** | [**interface{}**](interface{}.md) | Comma delimited list of specific fields to be returned. Format: topLevelNode, childNode, attribute | 
 **season** | [**interface{}**](interface{}.md) | Season of play | 

### Return type

 (empty response body)

### Authorization

No authorization required

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: Not defined

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints)
[[Back to Model list]](../README.md#documentation-for-models)
[[Back to README]](../README.md)

