/*
Copyright © 2024,2025 filifa

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"errors"
	"sort"
	"strings"

	"scm.dairydemon.net/filifa/mlbstats/api"
)

var statsAPIConfiguration = &api.Configuration{
	Host:          "statsapi.mlb.com",
	Scheme:        "https",
	DefaultHeader: make(map[string]string),
	UserAgent:     "OpenAPI-Generator/1.0.0/go",
	Debug:         false,
	Servers: api.ServerConfigurations{
		{
			URL:         "",
			Description: "No description provided",
		},
	},
	OperationServers: map[string]api.ServerConfigurations{},
}

var statsAPIClient = api.NewAPIClient(statsAPIConfiguration)

func keys[V any](m map[string]V) []string {
	keys := make([]string, len(m))

	i := 0
	for k := range m {
		keys[i] = k
		i++
	}

	return keys
}

func validateFlag[V any](v string, m map[string]V) error {
	var err error
	_, ok := m[v]
	if !ok {
		allowed := keys(m)
		sort.Strings(allowed)
		allowedList := strings.Join(allowed, ", ")
		err = errors.New("must be one of " + allowedList)
	}
	return err
}
