/*
Copyright © 2024,2025 filifa

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"context"
	"fmt"
	"io"
	"log"

	"github.com/spf13/cobra"
)

func content(cmd *cobra.Command, args []string) {
	req := statsAPIClient.GameAPI.Content(context.Background(), gamePk)

	resp, err := req.Execute()
	if err != nil {
		log.Fatal(err)
	}

	body, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(string(body))
}

// contentCmd represents the content command
var contentCmd = &cobra.Command{
	Use:   "content -g [gamePk]",
	Short: "Fetch game highlights",
	Long:  `Fetch game highlights`,
	Args:  cobra.NoArgs,
	Run:   content,
}

func init() {
	rootCmd.AddCommand(contentCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// contentCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	contentCmd.Flags().Int32VarP(&gamePk, "gamePk", "g", 0, "game PK")
	contentCmd.MarkFlagRequired("gamePk")
}
