/*
Copyright © 2024,2025 filifa

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
package cmd

import (
	"context"
	"fmt"
	"io"
	"log"

	"github.com/spf13/cobra"
)

var league leagueAbbr

func standings(cmd *cobra.Command, args []string) {
	var leagueIds []int
	leagueIds = append(leagueIds, leagueIDs[string(league)])

	req := statsAPIClient.StandingsAPI.Standings1(context.Background(), "regularSeason")

	req = req.LeagueId(leagueIds)

	resp, err := req.Execute()
	if err != nil {
		log.Fatal(err)
	}

	body, err := io.ReadAll(resp.Body)
	if err != nil {
		log.Fatal(err)
	}

	fmt.Println(string(body))
}

// standingsCmd represents the standings command
var standingsCmd = &cobra.Command{
	Use:   "standings -l [league]",
	Short: "Fetch league standings",
	Long:  `Fetch league standings`,
	Args:  cobra.NoArgs,
	Run:   standings,
}

func init() {
	rootCmd.AddCommand(standingsCmd)

	// Here you will define your flags and configuration settings.

	// Cobra supports Persistent Flags which will work for this command
	// and all subcommands, e.g.:
	// standingsCmd.PersistentFlags().String("foo", "", "A help for foo")

	// Cobra supports local flags which will only run when this command
	// is called directly, e.g.:
	// standingsCmd.Flags().BoolP("toggle", "t", false, "Help message for toggle")
	standingsCmd.Flags().VarP(&league, "league", "l", "league to get standings for")
	standingsCmd.MarkFlagRequired("league")
}
